package gdk

// #include <gdk/gdk.h>
// #include "gdk.go.h"
import "C"

const (
	KEY_VoidSymbol                  = uint(C.GDK_KEY_VoidSymbol)
	KEY_BackSpace                   = uint(C.GDK_KEY_BackSpace)
	KEY_Tab                         = uint(C.GDK_KEY_Tab)
	KEY_Linefeed                    = uint(C.GDK_KEY_Linefeed)
	KEY_Clear                       = uint(C.GDK_KEY_Clear)
	KEY_Return                      = uint(C.GDK_KEY_Return)
	KEY_Pause                       = uint(C.GDK_KEY_Pause)
	KEY_Scroll_Lock                 = uint(C.GDK_KEY_Scroll_Lock)
	KEY_Sys_Req                     = uint(C.GDK_KEY_Sys_Req)
	KEY_Escape                      = uint(C.GDK_KEY_Escape)
	KEY_Delete                      = uint(C.GDK_KEY_Delete)
	KEY_Multi_key                   = uint(C.GDK_KEY_Multi_key)
	KEY_Codeinput                   = uint(C.GDK_KEY_Codeinput)
	KEY_SingleCandidate             = uint(C.GDK_KEY_SingleCandidate)
	KEY_MultipleCandidate           = uint(C.GDK_KEY_MultipleCandidate)
	KEY_PreviousCandidate           = uint(C.GDK_KEY_PreviousCandidate)
	KEY_Kanji                       = uint(C.GDK_KEY_Kanji)
	KEY_Muhenkan                    = uint(C.GDK_KEY_Muhenkan)
	KEY_Henkan_Mode                 = uint(C.GDK_KEY_Henkan_Mode)
	KEY_Henkan                      = uint(C.GDK_KEY_Henkan)
	KEY_Romaji                      = uint(C.GDK_KEY_Romaji)
	KEY_Hiragana                    = uint(C.GDK_KEY_Hiragana)
	KEY_Katakana                    = uint(C.GDK_KEY_Katakana)
	KEY_Hiragana_Katakana           = uint(C.GDK_KEY_Hiragana_Katakana)
	KEY_Zenkaku                     = uint(C.GDK_KEY_Zenkaku)
	KEY_Hankaku                     = uint(C.GDK_KEY_Hankaku)
	KEY_Zenkaku_Hankaku             = uint(C.GDK_KEY_Zenkaku_Hankaku)
	KEY_Touroku                     = uint(C.GDK_KEY_Touroku)
	KEY_Massyo                      = uint(C.GDK_KEY_Massyo)
	KEY_Kana_Lock                   = uint(C.GDK_KEY_Kana_Lock)
	KEY_Kana_Shift                  = uint(C.GDK_KEY_Kana_Shift)
	KEY_Eisu_Shift                  = uint(C.GDK_KEY_Eisu_Shift)
	KEY_Eisu_toggle                 = uint(C.GDK_KEY_Eisu_toggle)
	KEY_Kanji_Bangou                = uint(C.GDK_KEY_Kanji_Bangou)
	KEY_Zen_Koho                    = uint(C.GDK_KEY_Zen_Koho)
	KEY_Mae_Koho                    = uint(C.GDK_KEY_Mae_Koho)
	KEY_Home                        = uint(C.GDK_KEY_Home)
	KEY_Left                        = uint(C.GDK_KEY_Left)
	KEY_Up                          = uint(C.GDK_KEY_Up)
	KEY_Right                       = uint(C.GDK_KEY_Right)
	KEY_Down                        = uint(C.GDK_KEY_Down)
	KEY_Prior                       = uint(C.GDK_KEY_Prior)
	KEY_Page_Up                     = uint(C.GDK_KEY_Page_Up)
	KEY_Next                        = uint(C.GDK_KEY_Next)
	KEY_Page_Down                   = uint(C.GDK_KEY_Page_Down)
	KEY_End                         = uint(C.GDK_KEY_End)
	KEY_Begin                       = uint(C.GDK_KEY_Begin)
	KEY_Select                      = uint(C.GDK_KEY_Select)
	KEY_Print                       = uint(C.GDK_KEY_Print)
	KEY_Execute                     = uint(C.GDK_KEY_Execute)
	KEY_Insert                      = uint(C.GDK_KEY_Insert)
	KEY_Undo                        = uint(C.GDK_KEY_Undo)
	KEY_Redo                        = uint(C.GDK_KEY_Redo)
	KEY_Menu                        = uint(C.GDK_KEY_Menu)
	KEY_Find                        = uint(C.GDK_KEY_Find)
	KEY_Cancel                      = uint(C.GDK_KEY_Cancel)
	KEY_Help                        = uint(C.GDK_KEY_Help)
	KEY_Break                       = uint(C.GDK_KEY_Break)
	KEY_Mode_switch                 = uint(C.GDK_KEY_Mode_switch)
	KEY_script_switch               = uint(C.GDK_KEY_script_switch)
	KEY_Num_Lock                    = uint(C.GDK_KEY_Num_Lock)
	KEY_KP_Space                    = uint(C.GDK_KEY_KP_Space)
	KEY_KP_Tab                      = uint(C.GDK_KEY_KP_Tab)
	KEY_KP_Enter                    = uint(C.GDK_KEY_KP_Enter)
	KEY_KP_F1                       = uint(C.GDK_KEY_KP_F1)
	KEY_KP_F2                       = uint(C.GDK_KEY_KP_F2)
	KEY_KP_F3                       = uint(C.GDK_KEY_KP_F3)
	KEY_KP_F4                       = uint(C.GDK_KEY_KP_F4)
	KEY_KP_Home                     = uint(C.GDK_KEY_KP_Home)
	KEY_KP_Left                     = uint(C.GDK_KEY_KP_Left)
	KEY_KP_Up                       = uint(C.GDK_KEY_KP_Up)
	KEY_KP_Right                    = uint(C.GDK_KEY_KP_Right)
	KEY_KP_Down                     = uint(C.GDK_KEY_KP_Down)
	KEY_KP_Prior                    = uint(C.GDK_KEY_KP_Prior)
	KEY_KP_Page_Up                  = uint(C.GDK_KEY_KP_Page_Up)
	KEY_KP_Next                     = uint(C.GDK_KEY_KP_Next)
	KEY_KP_Page_Down                = uint(C.GDK_KEY_KP_Page_Down)
	KEY_KP_End                      = uint(C.GDK_KEY_KP_End)
	KEY_KP_Begin                    = uint(C.GDK_KEY_KP_Begin)
	KEY_KP_Insert                   = uint(C.GDK_KEY_KP_Insert)
	KEY_KP_Delete                   = uint(C.GDK_KEY_KP_Delete)
	KEY_KP_Equal                    = uint(C.GDK_KEY_KP_Equal)
	KEY_KP_Multiply                 = uint(C.GDK_KEY_KP_Multiply)
	KEY_KP_Add                      = uint(C.GDK_KEY_KP_Add)
	KEY_KP_Separator                = uint(C.GDK_KEY_KP_Separator)
	KEY_KP_Subtract                 = uint(C.GDK_KEY_KP_Subtract)
	KEY_KP_Decimal                  = uint(C.GDK_KEY_KP_Decimal)
	KEY_KP_Divide                   = uint(C.GDK_KEY_KP_Divide)
	KEY_KP_0                        = uint(C.GDK_KEY_KP_0)
	KEY_KP_1                        = uint(C.GDK_KEY_KP_1)
	KEY_KP_2                        = uint(C.GDK_KEY_KP_2)
	KEY_KP_3                        = uint(C.GDK_KEY_KP_3)
	KEY_KP_4                        = uint(C.GDK_KEY_KP_4)
	KEY_KP_5                        = uint(C.GDK_KEY_KP_5)
	KEY_KP_6                        = uint(C.GDK_KEY_KP_6)
	KEY_KP_7                        = uint(C.GDK_KEY_KP_7)
	KEY_KP_8                        = uint(C.GDK_KEY_KP_8)
	KEY_KP_9                        = uint(C.GDK_KEY_KP_9)
	KEY_F1                          = uint(C.GDK_KEY_F1)
	KEY_F2                          = uint(C.GDK_KEY_F2)
	KEY_F3                          = uint(C.GDK_KEY_F3)
	KEY_F4                          = uint(C.GDK_KEY_F4)
	KEY_F5                          = uint(C.GDK_KEY_F5)
	KEY_F6                          = uint(C.GDK_KEY_F6)
	KEY_F7                          = uint(C.GDK_KEY_F7)
	KEY_F8                          = uint(C.GDK_KEY_F8)
	KEY_F9                          = uint(C.GDK_KEY_F9)
	KEY_F10                         = uint(C.GDK_KEY_F10)
	KEY_F11                         = uint(C.GDK_KEY_F11)
	KEY_L1                          = uint(C.GDK_KEY_L1)
	KEY_F12                         = uint(C.GDK_KEY_F12)
	KEY_L2                          = uint(C.GDK_KEY_L2)
	KEY_F13                         = uint(C.GDK_KEY_F13)
	KEY_L3                          = uint(C.GDK_KEY_L3)
	KEY_F14                         = uint(C.GDK_KEY_F14)
	KEY_L4                          = uint(C.GDK_KEY_L4)
	KEY_F15                         = uint(C.GDK_KEY_F15)
	KEY_L5                          = uint(C.GDK_KEY_L5)
	KEY_F16                         = uint(C.GDK_KEY_F16)
	KEY_L6                          = uint(C.GDK_KEY_L6)
	KEY_F17                         = uint(C.GDK_KEY_F17)
	KEY_L7                          = uint(C.GDK_KEY_L7)
	KEY_F18                         = uint(C.GDK_KEY_F18)
	KEY_L8                          = uint(C.GDK_KEY_L8)
	KEY_F19                         = uint(C.GDK_KEY_F19)
	KEY_L9                          = uint(C.GDK_KEY_L9)
	KEY_F20                         = uint(C.GDK_KEY_F20)
	KEY_L10                         = uint(C.GDK_KEY_L10)
	KEY_F21                         = uint(C.GDK_KEY_F21)
	KEY_R1                          = uint(C.GDK_KEY_R1)
	KEY_F22                         = uint(C.GDK_KEY_F22)
	KEY_R2                          = uint(C.GDK_KEY_R2)
	KEY_F23                         = uint(C.GDK_KEY_F23)
	KEY_R3                          = uint(C.GDK_KEY_R3)
	KEY_F24                         = uint(C.GDK_KEY_F24)
	KEY_R4                          = uint(C.GDK_KEY_R4)
	KEY_F25                         = uint(C.GDK_KEY_F25)
	KEY_R5                          = uint(C.GDK_KEY_R5)
	KEY_F26                         = uint(C.GDK_KEY_F26)
	KEY_R6                          = uint(C.GDK_KEY_R6)
	KEY_F27                         = uint(C.GDK_KEY_F27)
	KEY_R7                          = uint(C.GDK_KEY_R7)
	KEY_F28                         = uint(C.GDK_KEY_F28)
	KEY_R8                          = uint(C.GDK_KEY_R8)
	KEY_F29                         = uint(C.GDK_KEY_F29)
	KEY_R9                          = uint(C.GDK_KEY_R9)
	KEY_F30                         = uint(C.GDK_KEY_F30)
	KEY_R10                         = uint(C.GDK_KEY_R10)
	KEY_F31                         = uint(C.GDK_KEY_F31)
	KEY_R11                         = uint(C.GDK_KEY_R11)
	KEY_F32                         = uint(C.GDK_KEY_F32)
	KEY_R12                         = uint(C.GDK_KEY_R12)
	KEY_F33                         = uint(C.GDK_KEY_F33)
	KEY_R13                         = uint(C.GDK_KEY_R13)
	KEY_F34                         = uint(C.GDK_KEY_F34)
	KEY_R14                         = uint(C.GDK_KEY_R14)
	KEY_F35                         = uint(C.GDK_KEY_F35)
	KEY_R15                         = uint(C.GDK_KEY_R15)
	KEY_Shift_L                     = uint(C.GDK_KEY_Shift_L)
	KEY_Shift_R                     = uint(C.GDK_KEY_Shift_R)
	KEY_Control_L                   = uint(C.GDK_KEY_Control_L)
	KEY_Control_R                   = uint(C.GDK_KEY_Control_R)
	KEY_Caps_Lock                   = uint(C.GDK_KEY_Caps_Lock)
	KEY_Shift_Lock                  = uint(C.GDK_KEY_Shift_Lock)
	KEY_Meta_L                      = uint(C.GDK_KEY_Meta_L)
	KEY_Meta_R                      = uint(C.GDK_KEY_Meta_R)
	KEY_Alt_L                       = uint(C.GDK_KEY_Alt_L)
	KEY_Alt_R                       = uint(C.GDK_KEY_Alt_R)
	KEY_Super_L                     = uint(C.GDK_KEY_Super_L)
	KEY_Super_R                     = uint(C.GDK_KEY_Super_R)
	KEY_Hyper_L                     = uint(C.GDK_KEY_Hyper_L)
	KEY_Hyper_R                     = uint(C.GDK_KEY_Hyper_R)
	KEY_ISO_Lock                    = uint(C.GDK_KEY_ISO_Lock)
	KEY_ISO_Level2_Latch            = uint(C.GDK_KEY_ISO_Level2_Latch)
	KEY_ISO_Level3_Shift            = uint(C.GDK_KEY_ISO_Level3_Shift)
	KEY_ISO_Level3_Latch            = uint(C.GDK_KEY_ISO_Level3_Latch)
	KEY_ISO_Level3_Lock             = uint(C.GDK_KEY_ISO_Level3_Lock)
	KEY_ISO_Level5_Shift            = uint(C.GDK_KEY_ISO_Level5_Shift)
	KEY_ISO_Level5_Latch            = uint(C.GDK_KEY_ISO_Level5_Latch)
	KEY_ISO_Level5_Lock             = uint(C.GDK_KEY_ISO_Level5_Lock)
	KEY_ISO_Group_Shift             = uint(C.GDK_KEY_ISO_Group_Shift)
	KEY_ISO_Group_Latch             = uint(C.GDK_KEY_ISO_Group_Latch)
	KEY_ISO_Group_Lock              = uint(C.GDK_KEY_ISO_Group_Lock)
	KEY_ISO_Next_Group              = uint(C.GDK_KEY_ISO_Next_Group)
	KEY_ISO_Next_Group_Lock         = uint(C.GDK_KEY_ISO_Next_Group_Lock)
	KEY_ISO_Prev_Group              = uint(C.GDK_KEY_ISO_Prev_Group)
	KEY_ISO_Prev_Group_Lock         = uint(C.GDK_KEY_ISO_Prev_Group_Lock)
	KEY_ISO_First_Group             = uint(C.GDK_KEY_ISO_First_Group)
	KEY_ISO_First_Group_Lock        = uint(C.GDK_KEY_ISO_First_Group_Lock)
	KEY_ISO_Last_Group              = uint(C.GDK_KEY_ISO_Last_Group)
	KEY_ISO_Last_Group_Lock         = uint(C.GDK_KEY_ISO_Last_Group_Lock)
	KEY_ISO_Left_Tab                = uint(C.GDK_KEY_ISO_Left_Tab)
	KEY_ISO_Move_Line_Up            = uint(C.GDK_KEY_ISO_Move_Line_Up)
	KEY_ISO_Move_Line_Down          = uint(C.GDK_KEY_ISO_Move_Line_Down)
	KEY_ISO_Partial_Line_Up         = uint(C.GDK_KEY_ISO_Partial_Line_Up)
	KEY_ISO_Partial_Line_Down       = uint(C.GDK_KEY_ISO_Partial_Line_Down)
	KEY_ISO_Partial_Space_Left      = uint(C.GDK_KEY_ISO_Partial_Space_Left)
	KEY_ISO_Partial_Space_Right     = uint(C.GDK_KEY_ISO_Partial_Space_Right)
	KEY_ISO_Set_Margin_Left         = uint(C.GDK_KEY_ISO_Set_Margin_Left)
	KEY_ISO_Set_Margin_Right        = uint(C.GDK_KEY_ISO_Set_Margin_Right)
	KEY_ISO_Release_Margin_Left     = uint(C.GDK_KEY_ISO_Release_Margin_Left)
	KEY_ISO_Release_Margin_Right    = uint(C.GDK_KEY_ISO_Release_Margin_Right)
	KEY_ISO_Release_Both_Margins    = uint(C.GDK_KEY_ISO_Release_Both_Margins)
	KEY_ISO_Fast_Cursor_Left        = uint(C.GDK_KEY_ISO_Fast_Cursor_Left)
	KEY_ISO_Fast_Cursor_Right       = uint(C.GDK_KEY_ISO_Fast_Cursor_Right)
	KEY_ISO_Fast_Cursor_Up          = uint(C.GDK_KEY_ISO_Fast_Cursor_Up)
	KEY_ISO_Fast_Cursor_Down        = uint(C.GDK_KEY_ISO_Fast_Cursor_Down)
	KEY_ISO_Continuous_Underline    = uint(C.GDK_KEY_ISO_Continuous_Underline)
	KEY_ISO_Discontinuous_Underline = uint(C.GDK_KEY_ISO_Discontinuous_Underline)
	KEY_ISO_Emphasize               = uint(C.GDK_KEY_ISO_Emphasize)
	KEY_ISO_Center_Object           = uint(C.GDK_KEY_ISO_Center_Object)
	KEY_ISO_Enter                   = uint(C.GDK_KEY_ISO_Enter)
	KEY_dead_grave                  = uint(C.GDK_KEY_dead_grave)
	KEY_dead_acute                  = uint(C.GDK_KEY_dead_acute)
	KEY_dead_circumflex             = uint(C.GDK_KEY_dead_circumflex)
	KEY_dead_tilde                  = uint(C.GDK_KEY_dead_tilde)
	KEY_dead_perispomeni            = uint(C.GDK_KEY_dead_perispomeni)
	KEY_dead_macron                 = uint(C.GDK_KEY_dead_macron)
	KEY_dead_breve                  = uint(C.GDK_KEY_dead_breve)
	KEY_dead_abovedot               = uint(C.GDK_KEY_dead_abovedot)
	KEY_dead_diaeresis              = uint(C.GDK_KEY_dead_diaeresis)
	KEY_dead_abovering              = uint(C.GDK_KEY_dead_abovering)
	KEY_dead_doubleacute            = uint(C.GDK_KEY_dead_doubleacute)
	KEY_dead_caron                  = uint(C.GDK_KEY_dead_caron)
	KEY_dead_cedilla                = uint(C.GDK_KEY_dead_cedilla)
	KEY_dead_ogonek                 = uint(C.GDK_KEY_dead_ogonek)
	KEY_dead_iota                   = uint(C.GDK_KEY_dead_iota)
	KEY_dead_voiced_sound           = uint(C.GDK_KEY_dead_voiced_sound)
	KEY_dead_semivoiced_sound       = uint(C.GDK_KEY_dead_semivoiced_sound)
	KEY_dead_belowdot               = uint(C.GDK_KEY_dead_belowdot)
	KEY_dead_hook                   = uint(C.GDK_KEY_dead_hook)
	KEY_dead_horn                   = uint(C.GDK_KEY_dead_horn)
	KEY_dead_stroke                 = uint(C.GDK_KEY_dead_stroke)
	KEY_dead_abovecomma             = uint(C.GDK_KEY_dead_abovecomma)
	KEY_dead_psili                  = uint(C.GDK_KEY_dead_psili)
	KEY_dead_abovereversedcomma     = uint(C.GDK_KEY_dead_abovereversedcomma)
	KEY_dead_dasia                  = uint(C.GDK_KEY_dead_dasia)
	KEY_dead_doublegrave            = uint(C.GDK_KEY_dead_doublegrave)
	KEY_dead_belowring              = uint(C.GDK_KEY_dead_belowring)
	KEY_dead_belowmacron            = uint(C.GDK_KEY_dead_belowmacron)
	KEY_dead_belowcircumflex        = uint(C.GDK_KEY_dead_belowcircumflex)
	KEY_dead_belowtilde             = uint(C.GDK_KEY_dead_belowtilde)
	KEY_dead_belowbreve             = uint(C.GDK_KEY_dead_belowbreve)
	KEY_dead_belowdiaeresis         = uint(C.GDK_KEY_dead_belowdiaeresis)
	KEY_dead_invertedbreve          = uint(C.GDK_KEY_dead_invertedbreve)
	KEY_dead_belowcomma             = uint(C.GDK_KEY_dead_belowcomma)
	KEY_dead_currency               = uint(C.GDK_KEY_dead_currency)
	KEY_dead_a                      = uint(C.GDK_KEY_dead_a)
	KEY_dead_A                      = uint(C.GDK_KEY_dead_A)
	KEY_dead_e                      = uint(C.GDK_KEY_dead_e)
	KEY_dead_E                      = uint(C.GDK_KEY_dead_E)
	KEY_dead_i                      = uint(C.GDK_KEY_dead_i)
	KEY_dead_I                      = uint(C.GDK_KEY_dead_I)
	KEY_dead_o                      = uint(C.GDK_KEY_dead_o)
	KEY_dead_O                      = uint(C.GDK_KEY_dead_O)
	KEY_dead_u                      = uint(C.GDK_KEY_dead_u)
	KEY_dead_U                      = uint(C.GDK_KEY_dead_U)
	KEY_dead_small_schwa            = uint(C.GDK_KEY_dead_small_schwa)
	KEY_dead_capital_schwa          = uint(C.GDK_KEY_dead_capital_schwa)
	KEY_dead_greek                  = uint(C.GDK_KEY_dead_greek)
	KEY_First_Virtual_Screen        = uint(C.GDK_KEY_First_Virtual_Screen)
	KEY_Prev_Virtual_Screen         = uint(C.GDK_KEY_Prev_Virtual_Screen)
	KEY_Next_Virtual_Screen         = uint(C.GDK_KEY_Next_Virtual_Screen)
	KEY_Last_Virtual_Screen         = uint(C.GDK_KEY_Last_Virtual_Screen)
	KEY_Terminate_Server            = uint(C.GDK_KEY_Terminate_Server)
	KEY_AccessX_Enable              = uint(C.GDK_KEY_AccessX_Enable)
	KEY_AccessX_Feedback_Enable     = uint(C.GDK_KEY_AccessX_Feedback_Enable)
	KEY_RepeatKeys_Enable           = uint(C.GDK_KEY_RepeatKeys_Enable)
	KEY_SlowKeys_Enable             = uint(C.GDK_KEY_SlowKeys_Enable)
	KEY_BounceKeys_Enable           = uint(C.GDK_KEY_BounceKeys_Enable)
	KEY_StickyKeys_Enable           = uint(C.GDK_KEY_StickyKeys_Enable)
	KEY_MouseKeys_Enable            = uint(C.GDK_KEY_MouseKeys_Enable)
	KEY_MouseKeys_Accel_Enable      = uint(C.GDK_KEY_MouseKeys_Accel_Enable)
	KEY_Overlay1_Enable             = uint(C.GDK_KEY_Overlay1_Enable)
	KEY_Overlay2_Enable             = uint(C.GDK_KEY_Overlay2_Enable)
	KEY_AudibleBell_Enable          = uint(C.GDK_KEY_AudibleBell_Enable)
	KEY_Pointer_Left                = uint(C.GDK_KEY_Pointer_Left)
	KEY_Pointer_Right               = uint(C.GDK_KEY_Pointer_Right)
	KEY_Pointer_Up                  = uint(C.GDK_KEY_Pointer_Up)
	KEY_Pointer_Down                = uint(C.GDK_KEY_Pointer_Down)
	KEY_Pointer_UpLeft              = uint(C.GDK_KEY_Pointer_UpLeft)
	KEY_Pointer_UpRight             = uint(C.GDK_KEY_Pointer_UpRight)
	KEY_Pointer_DownLeft            = uint(C.GDK_KEY_Pointer_DownLeft)
	KEY_Pointer_DownRight           = uint(C.GDK_KEY_Pointer_DownRight)
	KEY_Pointer_Button_Dflt         = uint(C.GDK_KEY_Pointer_Button_Dflt)
	KEY_Pointer_Button1             = uint(C.GDK_KEY_Pointer_Button1)
	KEY_Pointer_Button2             = uint(C.GDK_KEY_Pointer_Button2)
	KEY_Pointer_Button3             = uint(C.GDK_KEY_Pointer_Button3)
	KEY_Pointer_Button4             = uint(C.GDK_KEY_Pointer_Button4)
	KEY_Pointer_Button5             = uint(C.GDK_KEY_Pointer_Button5)
	KEY_Pointer_DblClick_Dflt       = uint(C.GDK_KEY_Pointer_DblClick_Dflt)
	KEY_Pointer_DblClick1           = uint(C.GDK_KEY_Pointer_DblClick1)
	KEY_Pointer_DblClick2           = uint(C.GDK_KEY_Pointer_DblClick2)
	KEY_Pointer_DblClick3           = uint(C.GDK_KEY_Pointer_DblClick3)
	KEY_Pointer_DblClick4           = uint(C.GDK_KEY_Pointer_DblClick4)
	KEY_Pointer_DblClick5           = uint(C.GDK_KEY_Pointer_DblClick5)
	KEY_Pointer_Drag_Dflt           = uint(C.GDK_KEY_Pointer_Drag_Dflt)
	KEY_Pointer_Drag1               = uint(C.GDK_KEY_Pointer_Drag1)
	KEY_Pointer_Drag2               = uint(C.GDK_KEY_Pointer_Drag2)
	KEY_Pointer_Drag3               = uint(C.GDK_KEY_Pointer_Drag3)
	KEY_Pointer_Drag4               = uint(C.GDK_KEY_Pointer_Drag4)
	KEY_Pointer_Drag5               = uint(C.GDK_KEY_Pointer_Drag5)
	KEY_Pointer_EnableKeys          = uint(C.GDK_KEY_Pointer_EnableKeys)
	KEY_Pointer_Accelerate          = uint(C.GDK_KEY_Pointer_Accelerate)
	KEY_Pointer_DfltBtnNext         = uint(C.GDK_KEY_Pointer_DfltBtnNext)
	KEY_Pointer_DfltBtnPrev         = uint(C.GDK_KEY_Pointer_DfltBtnPrev)
	KEY_ch                          = uint(C.GDK_KEY_ch)
	KEY_Ch                          = uint(C.GDK_KEY_Ch)
	KEY_CH                          = uint(C.GDK_KEY_CH)
	KEY_c_h                         = uint(C.GDK_KEY_c_h)
	KEY_C_h                         = uint(C.GDK_KEY_C_h)
	KEY_C_H                         = uint(C.GDK_KEY_C_H)
	KEY_3270_Duplicate              = uint(C.GDK_KEY_3270_Duplicate)
	KEY_3270_FieldMark              = uint(C.GDK_KEY_3270_FieldMark)
	KEY_3270_Right2                 = uint(C.GDK_KEY_3270_Right2)
	KEY_3270_Left2                  = uint(C.GDK_KEY_3270_Left2)
	KEY_3270_BackTab                = uint(C.GDK_KEY_3270_BackTab)
	KEY_3270_EraseEOF               = uint(C.GDK_KEY_3270_EraseEOF)
	KEY_3270_EraseInput             = uint(C.GDK_KEY_3270_EraseInput)
	KEY_3270_Reset                  = uint(C.GDK_KEY_3270_Reset)
	KEY_3270_Quit                   = uint(C.GDK_KEY_3270_Quit)
	KEY_3270_PA1                    = uint(C.GDK_KEY_3270_PA1)
	KEY_3270_PA2                    = uint(C.GDK_KEY_3270_PA2)
	KEY_3270_PA3                    = uint(C.GDK_KEY_3270_PA3)
	KEY_3270_Test                   = uint(C.GDK_KEY_3270_Test)
	KEY_3270_Attn                   = uint(C.GDK_KEY_3270_Attn)
	KEY_3270_CursorBlink            = uint(C.GDK_KEY_3270_CursorBlink)
	KEY_3270_AltCursor              = uint(C.GDK_KEY_3270_AltCursor)
	KEY_3270_KeyClick               = uint(C.GDK_KEY_3270_KeyClick)
	KEY_3270_Jump                   = uint(C.GDK_KEY_3270_Jump)
	KEY_3270_Ident                  = uint(C.GDK_KEY_3270_Ident)
	KEY_3270_Rule                   = uint(C.GDK_KEY_3270_Rule)
	KEY_3270_Copy                   = uint(C.GDK_KEY_3270_Copy)
	KEY_3270_Play                   = uint(C.GDK_KEY_3270_Play)
	KEY_3270_Setup                  = uint(C.GDK_KEY_3270_Setup)
	KEY_3270_Record                 = uint(C.GDK_KEY_3270_Record)
	KEY_3270_ChangeScreen           = uint(C.GDK_KEY_3270_ChangeScreen)
	KEY_3270_DeleteWord             = uint(C.GDK_KEY_3270_DeleteWord)
	KEY_3270_ExSelect               = uint(C.GDK_KEY_3270_ExSelect)
	KEY_3270_CursorSelect           = uint(C.GDK_KEY_3270_CursorSelect)
	KEY_3270_PrintScreen            = uint(C.GDK_KEY_3270_PrintScreen)
	KEY_3270_Enter                  = uint(C.GDK_KEY_3270_Enter)
	KEY_space                       = uint(C.GDK_KEY_space)
	KEY_exclam                      = uint(C.GDK_KEY_exclam)
	KEY_quotedbl                    = uint(C.GDK_KEY_quotedbl)
	KEY_numbersign                  = uint(C.GDK_KEY_numbersign)
	KEY_dollar                      = uint(C.GDK_KEY_dollar)
	KEY_percent                     = uint(C.GDK_KEY_percent)
	KEY_ampersand                   = uint(C.GDK_KEY_ampersand)
	KEY_apostrophe                  = uint(C.GDK_KEY_apostrophe)
	KEY_quoteright                  = uint(C.GDK_KEY_quoteright)
	KEY_parenleft                   = uint(C.GDK_KEY_parenleft)
	KEY_parenright                  = uint(C.GDK_KEY_parenright)
	KEY_asterisk                    = uint(C.GDK_KEY_asterisk)
	KEY_plus                        = uint(C.GDK_KEY_plus)
	KEY_comma                       = uint(C.GDK_KEY_comma)
	KEY_minus                       = uint(C.GDK_KEY_minus)
	KEY_period                      = uint(C.GDK_KEY_period)
	KEY_slash                       = uint(C.GDK_KEY_slash)
	KEY_0                           = uint(C.GDK_KEY_0)
	KEY_1                           = uint(C.GDK_KEY_1)
	KEY_2                           = uint(C.GDK_KEY_2)
	KEY_3                           = uint(C.GDK_KEY_3)
	KEY_4                           = uint(C.GDK_KEY_4)
	KEY_5                           = uint(C.GDK_KEY_5)
	KEY_6                           = uint(C.GDK_KEY_6)
	KEY_7                           = uint(C.GDK_KEY_7)
	KEY_8                           = uint(C.GDK_KEY_8)
	KEY_9                           = uint(C.GDK_KEY_9)
	KEY_colon                       = uint(C.GDK_KEY_colon)
	KEY_semicolon                   = uint(C.GDK_KEY_semicolon)
	KEY_less                        = uint(C.GDK_KEY_less)
	KEY_equal                       = uint(C.GDK_KEY_equal)
	KEY_greater                     = uint(C.GDK_KEY_greater)
	KEY_question                    = uint(C.GDK_KEY_question)
	KEY_at                          = uint(C.GDK_KEY_at)
	KEY_A                           = uint(C.GDK_KEY_A)
	KEY_B                           = uint(C.GDK_KEY_B)
	KEY_C                           = uint(C.GDK_KEY_C)
	KEY_D                           = uint(C.GDK_KEY_D)
	KEY_E                           = uint(C.GDK_KEY_E)
	KEY_F                           = uint(C.GDK_KEY_F)
	KEY_G                           = uint(C.GDK_KEY_G)
	KEY_H                           = uint(C.GDK_KEY_H)
	KEY_I                           = uint(C.GDK_KEY_I)
	KEY_J                           = uint(C.GDK_KEY_J)
	KEY_K                           = uint(C.GDK_KEY_K)
	KEY_L                           = uint(C.GDK_KEY_L)
	KEY_M                           = uint(C.GDK_KEY_M)
	KEY_N                           = uint(C.GDK_KEY_N)
	KEY_O                           = uint(C.GDK_KEY_O)
	KEY_P                           = uint(C.GDK_KEY_P)
	KEY_Q                           = uint(C.GDK_KEY_Q)
	KEY_R                           = uint(C.GDK_KEY_R)
	KEY_S                           = uint(C.GDK_KEY_S)
	KEY_T                           = uint(C.GDK_KEY_T)
	KEY_U                           = uint(C.GDK_KEY_U)
	KEY_V                           = uint(C.GDK_KEY_V)
	KEY_W                           = uint(C.GDK_KEY_W)
	KEY_X                           = uint(C.GDK_KEY_X)
	KEY_Y                           = uint(C.GDK_KEY_Y)
	KEY_Z                           = uint(C.GDK_KEY_Z)
	KEY_bracketleft                 = uint(C.GDK_KEY_bracketleft)
	KEY_backslash                   = uint(C.GDK_KEY_backslash)
	KEY_bracketright                = uint(C.GDK_KEY_bracketright)
	KEY_asciicircum                 = uint(C.GDK_KEY_asciicircum)
	KEY_underscore                  = uint(C.GDK_KEY_underscore)
	KEY_grave                       = uint(C.GDK_KEY_grave)
	KEY_quoteleft                   = uint(C.GDK_KEY_quoteleft)
	KEY_a                           = uint(C.GDK_KEY_a)
	KEY_b                           = uint(C.GDK_KEY_b)
	KEY_c                           = uint(C.GDK_KEY_c)
	KEY_d                           = uint(C.GDK_KEY_d)
	KEY_e                           = uint(C.GDK_KEY_e)
	KEY_f                           = uint(C.GDK_KEY_f)
	KEY_g                           = uint(C.GDK_KEY_g)
	KEY_h                           = uint(C.GDK_KEY_h)
	KEY_i                           = uint(C.GDK_KEY_i)
	KEY_j                           = uint(C.GDK_KEY_j)
	KEY_k                           = uint(C.GDK_KEY_k)
	KEY_l                           = uint(C.GDK_KEY_l)
	KEY_m                           = uint(C.GDK_KEY_m)
	KEY_n                           = uint(C.GDK_KEY_n)
	KEY_o                           = uint(C.GDK_KEY_o)
	KEY_p                           = uint(C.GDK_KEY_p)
	KEY_q                           = uint(C.GDK_KEY_q)
	KEY_r                           = uint(C.GDK_KEY_r)
	KEY_s                           = uint(C.GDK_KEY_s)
	KEY_t                           = uint(C.GDK_KEY_t)
	KEY_u                           = uint(C.GDK_KEY_u)
	KEY_v                           = uint(C.GDK_KEY_v)
	KEY_w                           = uint(C.GDK_KEY_w)
	KEY_x                           = uint(C.GDK_KEY_x)
	KEY_y                           = uint(C.GDK_KEY_y)
	KEY_z                           = uint(C.GDK_KEY_z)
	KEY_braceleft                   = uint(C.GDK_KEY_braceleft)
	KEY_bar                         = uint(C.GDK_KEY_bar)
	KEY_braceright                  = uint(C.GDK_KEY_braceright)
	KEY_asciitilde                  = uint(C.GDK_KEY_asciitilde)
	KEY_nobreakspace                = uint(C.GDK_KEY_nobreakspace)
	KEY_exclamdown                  = uint(C.GDK_KEY_exclamdown)
	KEY_cent                        = uint(C.GDK_KEY_cent)
	KEY_sterling                    = uint(C.GDK_KEY_sterling)
	KEY_currency                    = uint(C.GDK_KEY_currency)
	KEY_yen                         = uint(C.GDK_KEY_yen)
	KEY_brokenbar                   = uint(C.GDK_KEY_brokenbar)
	KEY_section                     = uint(C.GDK_KEY_section)
	KEY_diaeresis                   = uint(C.GDK_KEY_diaeresis)
	KEY_copyright                   = uint(C.GDK_KEY_copyright)
	KEY_ordfeminine                 = uint(C.GDK_KEY_ordfeminine)
	KEY_guillemotleft               = uint(C.GDK_KEY_guillemotleft)
	KEY_notsign                     = uint(C.GDK_KEY_notsign)
	KEY_hyphen                      = uint(C.GDK_KEY_hyphen)
	KEY_registered                  = uint(C.GDK_KEY_registered)
	KEY_macron                      = uint(C.GDK_KEY_macron)
	KEY_degree                      = uint(C.GDK_KEY_degree)
	KEY_plusminus                   = uint(C.GDK_KEY_plusminus)
	KEY_twosuperior                 = uint(C.GDK_KEY_twosuperior)
	KEY_threesuperior               = uint(C.GDK_KEY_threesuperior)
	KEY_acute                       = uint(C.GDK_KEY_acute)
	KEY_mu                          = uint(C.GDK_KEY_mu)
	KEY_paragraph                   = uint(C.GDK_KEY_paragraph)
	KEY_periodcentered              = uint(C.GDK_KEY_periodcentered)
	KEY_cedilla                     = uint(C.GDK_KEY_cedilla)
	KEY_onesuperior                 = uint(C.GDK_KEY_onesuperior)
	KEY_masculine                   = uint(C.GDK_KEY_masculine)
	KEY_guillemotright              = uint(C.GDK_KEY_guillemotright)
	KEY_onequarter                  = uint(C.GDK_KEY_onequarter)
	KEY_onehalf                     = uint(C.GDK_KEY_onehalf)
	KEY_threequarters               = uint(C.GDK_KEY_threequarters)
	KEY_questiondown                = uint(C.GDK_KEY_questiondown)
	KEY_Agrave                      = uint(C.GDK_KEY_Agrave)
	KEY_Aacute                      = uint(C.GDK_KEY_Aacute)
	KEY_Acircumflex                 = uint(C.GDK_KEY_Acircumflex)
	KEY_Atilde                      = uint(C.GDK_KEY_Atilde)
	KEY_Adiaeresis                  = uint(C.GDK_KEY_Adiaeresis)
	KEY_Aring                       = uint(C.GDK_KEY_Aring)
	KEY_AE                          = uint(C.GDK_KEY_AE)
	KEY_Ccedilla                    = uint(C.GDK_KEY_Ccedilla)
	KEY_Egrave                      = uint(C.GDK_KEY_Egrave)
	KEY_Eacute                      = uint(C.GDK_KEY_Eacute)
	KEY_Ecircumflex                 = uint(C.GDK_KEY_Ecircumflex)
	KEY_Ediaeresis                  = uint(C.GDK_KEY_Ediaeresis)
	KEY_Igrave                      = uint(C.GDK_KEY_Igrave)
	KEY_Iacute                      = uint(C.GDK_KEY_Iacute)
	KEY_Icircumflex                 = uint(C.GDK_KEY_Icircumflex)
	KEY_Idiaeresis                  = uint(C.GDK_KEY_Idiaeresis)
	KEY_ETH                         = uint(C.GDK_KEY_ETH)
	KEY_Eth                         = uint(C.GDK_KEY_Eth)
	KEY_Ntilde                      = uint(C.GDK_KEY_Ntilde)
	KEY_Ograve                      = uint(C.GDK_KEY_Ograve)
	KEY_Oacute                      = uint(C.GDK_KEY_Oacute)
	KEY_Ocircumflex                 = uint(C.GDK_KEY_Ocircumflex)
	KEY_Otilde                      = uint(C.GDK_KEY_Otilde)
	KEY_Odiaeresis                  = uint(C.GDK_KEY_Odiaeresis)
	KEY_multiply                    = uint(C.GDK_KEY_multiply)
	KEY_Oslash                      = uint(C.GDK_KEY_Oslash)
	KEY_Ooblique                    = uint(C.GDK_KEY_Ooblique)
	KEY_Ugrave                      = uint(C.GDK_KEY_Ugrave)
	KEY_Uacute                      = uint(C.GDK_KEY_Uacute)
	KEY_Ucircumflex                 = uint(C.GDK_KEY_Ucircumflex)
	KEY_Udiaeresis                  = uint(C.GDK_KEY_Udiaeresis)
	KEY_Yacute                      = uint(C.GDK_KEY_Yacute)
	KEY_THORN                       = uint(C.GDK_KEY_THORN)
	KEY_Thorn                       = uint(C.GDK_KEY_Thorn)
	KEY_ssharp                      = uint(C.GDK_KEY_ssharp)
	KEY_agrave                      = uint(C.GDK_KEY_agrave)
	KEY_aacute                      = uint(C.GDK_KEY_aacute)
	KEY_acircumflex                 = uint(C.GDK_KEY_acircumflex)
	KEY_atilde                      = uint(C.GDK_KEY_atilde)
	KEY_adiaeresis                  = uint(C.GDK_KEY_adiaeresis)
	KEY_aring                       = uint(C.GDK_KEY_aring)
	KEY_ae                          = uint(C.GDK_KEY_ae)
	KEY_ccedilla                    = uint(C.GDK_KEY_ccedilla)
	KEY_egrave                      = uint(C.GDK_KEY_egrave)
	KEY_eacute                      = uint(C.GDK_KEY_eacute)
	KEY_ecircumflex                 = uint(C.GDK_KEY_ecircumflex)
	KEY_ediaeresis                  = uint(C.GDK_KEY_ediaeresis)
	KEY_igrave                      = uint(C.GDK_KEY_igrave)
	KEY_iacute                      = uint(C.GDK_KEY_iacute)
	KEY_icircumflex                 = uint(C.GDK_KEY_icircumflex)
	KEY_idiaeresis                  = uint(C.GDK_KEY_idiaeresis)
	KEY_eth                         = uint(C.GDK_KEY_eth)
	KEY_ntilde                      = uint(C.GDK_KEY_ntilde)
	KEY_ograve                      = uint(C.GDK_KEY_ograve)
	KEY_oacute                      = uint(C.GDK_KEY_oacute)
	KEY_ocircumflex                 = uint(C.GDK_KEY_ocircumflex)
	KEY_otilde                      = uint(C.GDK_KEY_otilde)
	KEY_odiaeresis                  = uint(C.GDK_KEY_odiaeresis)
	KEY_division                    = uint(C.GDK_KEY_division)
	KEY_oslash                      = uint(C.GDK_KEY_oslash)
	KEY_ooblique                    = uint(C.GDK_KEY_ooblique)
	KEY_ugrave                      = uint(C.GDK_KEY_ugrave)
	KEY_uacute                      = uint(C.GDK_KEY_uacute)
	KEY_ucircumflex                 = uint(C.GDK_KEY_ucircumflex)
	KEY_udiaeresis                  = uint(C.GDK_KEY_udiaeresis)
	KEY_yacute                      = uint(C.GDK_KEY_yacute)
	KEY_thorn                       = uint(C.GDK_KEY_thorn)
	KEY_ydiaeresis                  = uint(C.GDK_KEY_ydiaeresis)
	KEY_Aogonek                     = uint(C.GDK_KEY_Aogonek)
	KEY_breve                       = uint(C.GDK_KEY_breve)
	KEY_Lstroke                     = uint(C.GDK_KEY_Lstroke)
	KEY_Lcaron                      = uint(C.GDK_KEY_Lcaron)
	KEY_Sacute                      = uint(C.GDK_KEY_Sacute)
	KEY_Scaron                      = uint(C.GDK_KEY_Scaron)
	KEY_Scedilla                    = uint(C.GDK_KEY_Scedilla)
	KEY_Tcaron                      = uint(C.GDK_KEY_Tcaron)
	KEY_Zacute                      = uint(C.GDK_KEY_Zacute)
	KEY_Zcaron                      = uint(C.GDK_KEY_Zcaron)
	KEY_Zabovedot                   = uint(C.GDK_KEY_Zabovedot)
	KEY_aogonek                     = uint(C.GDK_KEY_aogonek)
	KEY_ogonek                      = uint(C.GDK_KEY_ogonek)
	KEY_lstroke                     = uint(C.GDK_KEY_lstroke)
	KEY_lcaron                      = uint(C.GDK_KEY_lcaron)
	KEY_sacute                      = uint(C.GDK_KEY_sacute)
	KEY_caron                       = uint(C.GDK_KEY_caron)
	KEY_scaron                      = uint(C.GDK_KEY_scaron)
	KEY_scedilla                    = uint(C.GDK_KEY_scedilla)
	KEY_tcaron                      = uint(C.GDK_KEY_tcaron)
	KEY_zacute                      = uint(C.GDK_KEY_zacute)
	KEY_doubleacute                 = uint(C.GDK_KEY_doubleacute)
	KEY_zcaron                      = uint(C.GDK_KEY_zcaron)
	KEY_zabovedot                   = uint(C.GDK_KEY_zabovedot)
	KEY_Racute                      = uint(C.GDK_KEY_Racute)
	KEY_Abreve                      = uint(C.GDK_KEY_Abreve)
	KEY_Lacute                      = uint(C.GDK_KEY_Lacute)
	KEY_Cacute                      = uint(C.GDK_KEY_Cacute)
	KEY_Ccaron                      = uint(C.GDK_KEY_Ccaron)
	KEY_Eogonek                     = uint(C.GDK_KEY_Eogonek)
	KEY_Ecaron                      = uint(C.GDK_KEY_Ecaron)
	KEY_Dcaron                      = uint(C.GDK_KEY_Dcaron)
	KEY_Dstroke                     = uint(C.GDK_KEY_Dstroke)
	KEY_Nacute                      = uint(C.GDK_KEY_Nacute)
	KEY_Ncaron                      = uint(C.GDK_KEY_Ncaron)
	KEY_Odoubleacute                = uint(C.GDK_KEY_Odoubleacute)
	KEY_Rcaron                      = uint(C.GDK_KEY_Rcaron)
	KEY_Uring                       = uint(C.GDK_KEY_Uring)
	KEY_Udoubleacute                = uint(C.GDK_KEY_Udoubleacute)
	KEY_Tcedilla                    = uint(C.GDK_KEY_Tcedilla)
	KEY_racute                      = uint(C.GDK_KEY_racute)
	KEY_abreve                      = uint(C.GDK_KEY_abreve)
	KEY_lacute                      = uint(C.GDK_KEY_lacute)
	KEY_cacute                      = uint(C.GDK_KEY_cacute)
	KEY_ccaron                      = uint(C.GDK_KEY_ccaron)
	KEY_eogonek                     = uint(C.GDK_KEY_eogonek)
	KEY_ecaron                      = uint(C.GDK_KEY_ecaron)
	KEY_dcaron                      = uint(C.GDK_KEY_dcaron)
	KEY_dstroke                     = uint(C.GDK_KEY_dstroke)
	KEY_nacute                      = uint(C.GDK_KEY_nacute)
	KEY_ncaron                      = uint(C.GDK_KEY_ncaron)
	KEY_odoubleacute                = uint(C.GDK_KEY_odoubleacute)
	KEY_rcaron                      = uint(C.GDK_KEY_rcaron)
	KEY_uring                       = uint(C.GDK_KEY_uring)
	KEY_udoubleacute                = uint(C.GDK_KEY_udoubleacute)
	KEY_tcedilla                    = uint(C.GDK_KEY_tcedilla)
	KEY_abovedot                    = uint(C.GDK_KEY_abovedot)
	KEY_Hstroke                     = uint(C.GDK_KEY_Hstroke)
	KEY_Hcircumflex                 = uint(C.GDK_KEY_Hcircumflex)
	KEY_Iabovedot                   = uint(C.GDK_KEY_Iabovedot)
	KEY_Gbreve                      = uint(C.GDK_KEY_Gbreve)
	KEY_Jcircumflex                 = uint(C.GDK_KEY_Jcircumflex)
	KEY_hstroke                     = uint(C.GDK_KEY_hstroke)
	KEY_hcircumflex                 = uint(C.GDK_KEY_hcircumflex)
	KEY_idotless                    = uint(C.GDK_KEY_idotless)
	KEY_gbreve                      = uint(C.GDK_KEY_gbreve)
	KEY_jcircumflex                 = uint(C.GDK_KEY_jcircumflex)
	KEY_Cabovedot                   = uint(C.GDK_KEY_Cabovedot)
	KEY_Ccircumflex                 = uint(C.GDK_KEY_Ccircumflex)
	KEY_Gabovedot                   = uint(C.GDK_KEY_Gabovedot)
	KEY_Gcircumflex                 = uint(C.GDK_KEY_Gcircumflex)
	KEY_Ubreve                      = uint(C.GDK_KEY_Ubreve)
	KEY_Scircumflex                 = uint(C.GDK_KEY_Scircumflex)
	KEY_cabovedot                   = uint(C.GDK_KEY_cabovedot)
	KEY_ccircumflex                 = uint(C.GDK_KEY_ccircumflex)
	KEY_gabovedot                   = uint(C.GDK_KEY_gabovedot)
	KEY_gcircumflex                 = uint(C.GDK_KEY_gcircumflex)
	KEY_ubreve                      = uint(C.GDK_KEY_ubreve)
	KEY_scircumflex                 = uint(C.GDK_KEY_scircumflex)
	KEY_kra                         = uint(C.GDK_KEY_kra)
	KEY_kappa                       = uint(C.GDK_KEY_kappa)
	KEY_Rcedilla                    = uint(C.GDK_KEY_Rcedilla)
	KEY_Itilde                      = uint(C.GDK_KEY_Itilde)
	KEY_Lcedilla                    = uint(C.GDK_KEY_Lcedilla)
	KEY_Emacron                     = uint(C.GDK_KEY_Emacron)
	KEY_Gcedilla                    = uint(C.GDK_KEY_Gcedilla)
	KEY_Tslash                      = uint(C.GDK_KEY_Tslash)
	KEY_rcedilla                    = uint(C.GDK_KEY_rcedilla)
	KEY_itilde                      = uint(C.GDK_KEY_itilde)
	KEY_lcedilla                    = uint(C.GDK_KEY_lcedilla)
	KEY_emacron                     = uint(C.GDK_KEY_emacron)
	KEY_gcedilla                    = uint(C.GDK_KEY_gcedilla)
	KEY_tslash                      = uint(C.GDK_KEY_tslash)
	KEY_ENG                         = uint(C.GDK_KEY_ENG)
	KEY_eng                         = uint(C.GDK_KEY_eng)
	KEY_Amacron                     = uint(C.GDK_KEY_Amacron)
	KEY_Iogonek                     = uint(C.GDK_KEY_Iogonek)
	KEY_Eabovedot                   = uint(C.GDK_KEY_Eabovedot)
	KEY_Imacron                     = uint(C.GDK_KEY_Imacron)
	KEY_Ncedilla                    = uint(C.GDK_KEY_Ncedilla)
	KEY_Omacron                     = uint(C.GDK_KEY_Omacron)
	KEY_Kcedilla                    = uint(C.GDK_KEY_Kcedilla)
	KEY_Uogonek                     = uint(C.GDK_KEY_Uogonek)
	KEY_Utilde                      = uint(C.GDK_KEY_Utilde)
	KEY_Umacron                     = uint(C.GDK_KEY_Umacron)
	KEY_amacron                     = uint(C.GDK_KEY_amacron)
	KEY_iogonek                     = uint(C.GDK_KEY_iogonek)
	KEY_eabovedot                   = uint(C.GDK_KEY_eabovedot)
	KEY_imacron                     = uint(C.GDK_KEY_imacron)
	KEY_ncedilla                    = uint(C.GDK_KEY_ncedilla)
	KEY_omacron                     = uint(C.GDK_KEY_omacron)
	KEY_kcedilla                    = uint(C.GDK_KEY_kcedilla)
	KEY_uogonek                     = uint(C.GDK_KEY_uogonek)
	KEY_utilde                      = uint(C.GDK_KEY_utilde)
	KEY_umacron                     = uint(C.GDK_KEY_umacron)
	KEY_Wcircumflex                 = uint(C.GDK_KEY_Wcircumflex)
	KEY_wcircumflex                 = uint(C.GDK_KEY_wcircumflex)
	KEY_Ycircumflex                 = uint(C.GDK_KEY_Ycircumflex)
	KEY_ycircumflex                 = uint(C.GDK_KEY_ycircumflex)
	KEY_Babovedot                   = uint(C.GDK_KEY_Babovedot)
	KEY_babovedot                   = uint(C.GDK_KEY_babovedot)
	KEY_Dabovedot                   = uint(C.GDK_KEY_Dabovedot)
	KEY_dabovedot                   = uint(C.GDK_KEY_dabovedot)
	KEY_Fabovedot                   = uint(C.GDK_KEY_Fabovedot)
	KEY_fabovedot                   = uint(C.GDK_KEY_fabovedot)
	KEY_Mabovedot                   = uint(C.GDK_KEY_Mabovedot)
	KEY_mabovedot                   = uint(C.GDK_KEY_mabovedot)
	KEY_Pabovedot                   = uint(C.GDK_KEY_Pabovedot)
	KEY_pabovedot                   = uint(C.GDK_KEY_pabovedot)
	KEY_Sabovedot                   = uint(C.GDK_KEY_Sabovedot)
	KEY_sabovedot                   = uint(C.GDK_KEY_sabovedot)
	KEY_Tabovedot                   = uint(C.GDK_KEY_Tabovedot)
	KEY_tabovedot                   = uint(C.GDK_KEY_tabovedot)
	KEY_Wgrave                      = uint(C.GDK_KEY_Wgrave)
	KEY_wgrave                      = uint(C.GDK_KEY_wgrave)
	KEY_Wacute                      = uint(C.GDK_KEY_Wacute)
	KEY_wacute                      = uint(C.GDK_KEY_wacute)
	KEY_Wdiaeresis                  = uint(C.GDK_KEY_Wdiaeresis)
	KEY_wdiaeresis                  = uint(C.GDK_KEY_wdiaeresis)
	KEY_Ygrave                      = uint(C.GDK_KEY_Ygrave)
	KEY_ygrave                      = uint(C.GDK_KEY_ygrave)
	KEY_OE                          = uint(C.GDK_KEY_OE)
	KEY_oe                          = uint(C.GDK_KEY_oe)
	KEY_Ydiaeresis                  = uint(C.GDK_KEY_Ydiaeresis)
	KEY_overline                    = uint(C.GDK_KEY_overline)
	KEY_kana_fullstop               = uint(C.GDK_KEY_kana_fullstop)
	KEY_kana_openingbracket         = uint(C.GDK_KEY_kana_openingbracket)
	KEY_kana_closingbracket         = uint(C.GDK_KEY_kana_closingbracket)
	KEY_kana_comma                  = uint(C.GDK_KEY_kana_comma)
	KEY_kana_conjunctive            = uint(C.GDK_KEY_kana_conjunctive)
	KEY_kana_middledot              = uint(C.GDK_KEY_kana_middledot)
	KEY_kana_WO                     = uint(C.GDK_KEY_kana_WO)
	KEY_kana_a                      = uint(C.GDK_KEY_kana_a)
	KEY_kana_i                      = uint(C.GDK_KEY_kana_i)
	KEY_kana_u                      = uint(C.GDK_KEY_kana_u)
	KEY_kana_e                      = uint(C.GDK_KEY_kana_e)
	KEY_kana_o                      = uint(C.GDK_KEY_kana_o)
	KEY_kana_ya                     = uint(C.GDK_KEY_kana_ya)
	KEY_kana_yu                     = uint(C.GDK_KEY_kana_yu)
	KEY_kana_yo                     = uint(C.GDK_KEY_kana_yo)
	KEY_kana_tsu                    = uint(C.GDK_KEY_kana_tsu)
	KEY_kana_tu                     = uint(C.GDK_KEY_kana_tu)
	KEY_prolongedsound              = uint(C.GDK_KEY_prolongedsound)
	KEY_kana_A                      = uint(C.GDK_KEY_kana_A)
	KEY_kana_I                      = uint(C.GDK_KEY_kana_I)
	KEY_kana_U                      = uint(C.GDK_KEY_kana_U)
	KEY_kana_E                      = uint(C.GDK_KEY_kana_E)
	KEY_kana_O                      = uint(C.GDK_KEY_kana_O)
	KEY_kana_KA                     = uint(C.GDK_KEY_kana_KA)
	KEY_kana_KI                     = uint(C.GDK_KEY_kana_KI)
	KEY_kana_KU                     = uint(C.GDK_KEY_kana_KU)
	KEY_kana_KE                     = uint(C.GDK_KEY_kana_KE)
	KEY_kana_KO                     = uint(C.GDK_KEY_kana_KO)
	KEY_kana_SA                     = uint(C.GDK_KEY_kana_SA)
	KEY_kana_SHI                    = uint(C.GDK_KEY_kana_SHI)
	KEY_kana_SU                     = uint(C.GDK_KEY_kana_SU)
	KEY_kana_SE                     = uint(C.GDK_KEY_kana_SE)
	KEY_kana_SO                     = uint(C.GDK_KEY_kana_SO)
	KEY_kana_TA                     = uint(C.GDK_KEY_kana_TA)
	KEY_kana_CHI                    = uint(C.GDK_KEY_kana_CHI)
	KEY_kana_TI                     = uint(C.GDK_KEY_kana_TI)
	KEY_kana_TSU                    = uint(C.GDK_KEY_kana_TSU)
	KEY_kana_TU                     = uint(C.GDK_KEY_kana_TU)
	KEY_kana_TE                     = uint(C.GDK_KEY_kana_TE)
	KEY_kana_TO                     = uint(C.GDK_KEY_kana_TO)
	KEY_kana_NA                     = uint(C.GDK_KEY_kana_NA)
	KEY_kana_NI                     = uint(C.GDK_KEY_kana_NI)
	KEY_kana_NU                     = uint(C.GDK_KEY_kana_NU)
	KEY_kana_NE                     = uint(C.GDK_KEY_kana_NE)
	KEY_kana_NO                     = uint(C.GDK_KEY_kana_NO)
	KEY_kana_HA                     = uint(C.GDK_KEY_kana_HA)
	KEY_kana_HI                     = uint(C.GDK_KEY_kana_HI)
	KEY_kana_FU                     = uint(C.GDK_KEY_kana_FU)
	KEY_kana_HU                     = uint(C.GDK_KEY_kana_HU)
	KEY_kana_HE                     = uint(C.GDK_KEY_kana_HE)
	KEY_kana_HO                     = uint(C.GDK_KEY_kana_HO)
	KEY_kana_MA                     = uint(C.GDK_KEY_kana_MA)
	KEY_kana_MI                     = uint(C.GDK_KEY_kana_MI)
	KEY_kana_MU                     = uint(C.GDK_KEY_kana_MU)
	KEY_kana_ME                     = uint(C.GDK_KEY_kana_ME)
	KEY_kana_MO                     = uint(C.GDK_KEY_kana_MO)
	KEY_kana_YA                     = uint(C.GDK_KEY_kana_YA)
	KEY_kana_YU                     = uint(C.GDK_KEY_kana_YU)
	KEY_kana_YO                     = uint(C.GDK_KEY_kana_YO)
	KEY_kana_RA                     = uint(C.GDK_KEY_kana_RA)
	KEY_kana_RI                     = uint(C.GDK_KEY_kana_RI)
	KEY_kana_RU                     = uint(C.GDK_KEY_kana_RU)
	KEY_kana_RE                     = uint(C.GDK_KEY_kana_RE)
	KEY_kana_RO                     = uint(C.GDK_KEY_kana_RO)
	KEY_kana_WA                     = uint(C.GDK_KEY_kana_WA)
	KEY_kana_N                      = uint(C.GDK_KEY_kana_N)
	KEY_voicedsound                 = uint(C.GDK_KEY_voicedsound)
	KEY_semivoicedsound             = uint(C.GDK_KEY_semivoicedsound)
	KEY_kana_switch                 = uint(C.GDK_KEY_kana_switch)
	KEY_Farsi_0                     = uint(C.GDK_KEY_Farsi_0)
	KEY_Farsi_1                     = uint(C.GDK_KEY_Farsi_1)
	KEY_Farsi_2                     = uint(C.GDK_KEY_Farsi_2)
	KEY_Farsi_3                     = uint(C.GDK_KEY_Farsi_3)
	KEY_Farsi_4                     = uint(C.GDK_KEY_Farsi_4)
	KEY_Farsi_5                     = uint(C.GDK_KEY_Farsi_5)
	KEY_Farsi_6                     = uint(C.GDK_KEY_Farsi_6)
	KEY_Farsi_7                     = uint(C.GDK_KEY_Farsi_7)
	KEY_Farsi_8                     = uint(C.GDK_KEY_Farsi_8)
	KEY_Farsi_9                     = uint(C.GDK_KEY_Farsi_9)
	KEY_Arabic_percent              = uint(C.GDK_KEY_Arabic_percent)
	KEY_Arabic_superscript_alef     = uint(C.GDK_KEY_Arabic_superscript_alef)
	KEY_Arabic_tteh                 = uint(C.GDK_KEY_Arabic_tteh)
	KEY_Arabic_peh                  = uint(C.GDK_KEY_Arabic_peh)
	KEY_Arabic_tcheh                = uint(C.GDK_KEY_Arabic_tcheh)
	KEY_Arabic_ddal                 = uint(C.GDK_KEY_Arabic_ddal)
	KEY_Arabic_rreh                 = uint(C.GDK_KEY_Arabic_rreh)
	KEY_Arabic_comma                = uint(C.GDK_KEY_Arabic_comma)
	KEY_Arabic_fullstop             = uint(C.GDK_KEY_Arabic_fullstop)
	KEY_Arabic_0                    = uint(C.GDK_KEY_Arabic_0)
	KEY_Arabic_1                    = uint(C.GDK_KEY_Arabic_1)
	KEY_Arabic_2                    = uint(C.GDK_KEY_Arabic_2)
	KEY_Arabic_3                    = uint(C.GDK_KEY_Arabic_3)
	KEY_Arabic_4                    = uint(C.GDK_KEY_Arabic_4)
	KEY_Arabic_5                    = uint(C.GDK_KEY_Arabic_5)
	KEY_Arabic_6                    = uint(C.GDK_KEY_Arabic_6)
	KEY_Arabic_7                    = uint(C.GDK_KEY_Arabic_7)
	KEY_Arabic_8                    = uint(C.GDK_KEY_Arabic_8)
	KEY_Arabic_9                    = uint(C.GDK_KEY_Arabic_9)
	KEY_Arabic_semicolon            = uint(C.GDK_KEY_Arabic_semicolon)
	KEY_Arabic_question_mark        = uint(C.GDK_KEY_Arabic_question_mark)
	KEY_Arabic_hamza                = uint(C.GDK_KEY_Arabic_hamza)
	KEY_Arabic_maddaonalef          = uint(C.GDK_KEY_Arabic_maddaonalef)
	KEY_Arabic_hamzaonalef          = uint(C.GDK_KEY_Arabic_hamzaonalef)
	KEY_Arabic_hamzaonwaw           = uint(C.GDK_KEY_Arabic_hamzaonwaw)
	KEY_Arabic_hamzaunderalef       = uint(C.GDK_KEY_Arabic_hamzaunderalef)
	KEY_Arabic_hamzaonyeh           = uint(C.GDK_KEY_Arabic_hamzaonyeh)
	KEY_Arabic_alef                 = uint(C.GDK_KEY_Arabic_alef)
	KEY_Arabic_beh                  = uint(C.GDK_KEY_Arabic_beh)
	KEY_Arabic_tehmarbuta           = uint(C.GDK_KEY_Arabic_tehmarbuta)
	KEY_Arabic_teh                  = uint(C.GDK_KEY_Arabic_teh)
	KEY_Arabic_theh                 = uint(C.GDK_KEY_Arabic_theh)
	KEY_Arabic_jeem                 = uint(C.GDK_KEY_Arabic_jeem)
	KEY_Arabic_hah                  = uint(C.GDK_KEY_Arabic_hah)
	KEY_Arabic_khah                 = uint(C.GDK_KEY_Arabic_khah)
	KEY_Arabic_dal                  = uint(C.GDK_KEY_Arabic_dal)
	KEY_Arabic_thal                 = uint(C.GDK_KEY_Arabic_thal)
	KEY_Arabic_ra                   = uint(C.GDK_KEY_Arabic_ra)
	KEY_Arabic_zain                 = uint(C.GDK_KEY_Arabic_zain)
	KEY_Arabic_seen                 = uint(C.GDK_KEY_Arabic_seen)
	KEY_Arabic_sheen                = uint(C.GDK_KEY_Arabic_sheen)
	KEY_Arabic_sad                  = uint(C.GDK_KEY_Arabic_sad)
	KEY_Arabic_dad                  = uint(C.GDK_KEY_Arabic_dad)
	KEY_Arabic_tah                  = uint(C.GDK_KEY_Arabic_tah)
	KEY_Arabic_zah                  = uint(C.GDK_KEY_Arabic_zah)
	KEY_Arabic_ain                  = uint(C.GDK_KEY_Arabic_ain)
	KEY_Arabic_ghain                = uint(C.GDK_KEY_Arabic_ghain)
	KEY_Arabic_tatweel              = uint(C.GDK_KEY_Arabic_tatweel)
	KEY_Arabic_feh                  = uint(C.GDK_KEY_Arabic_feh)
	KEY_Arabic_qaf                  = uint(C.GDK_KEY_Arabic_qaf)
	KEY_Arabic_kaf                  = uint(C.GDK_KEY_Arabic_kaf)
	KEY_Arabic_lam                  = uint(C.GDK_KEY_Arabic_lam)
	KEY_Arabic_meem                 = uint(C.GDK_KEY_Arabic_meem)
	KEY_Arabic_noon                 = uint(C.GDK_KEY_Arabic_noon)
	KEY_Arabic_ha                   = uint(C.GDK_KEY_Arabic_ha)
	KEY_Arabic_heh                  = uint(C.GDK_KEY_Arabic_heh)
	KEY_Arabic_waw                  = uint(C.GDK_KEY_Arabic_waw)
	KEY_Arabic_alefmaksura          = uint(C.GDK_KEY_Arabic_alefmaksura)
	KEY_Arabic_yeh                  = uint(C.GDK_KEY_Arabic_yeh)
	KEY_Arabic_fathatan             = uint(C.GDK_KEY_Arabic_fathatan)
	KEY_Arabic_dammatan             = uint(C.GDK_KEY_Arabic_dammatan)
	KEY_Arabic_kasratan             = uint(C.GDK_KEY_Arabic_kasratan)
	KEY_Arabic_fatha                = uint(C.GDK_KEY_Arabic_fatha)
	KEY_Arabic_damma                = uint(C.GDK_KEY_Arabic_damma)
	KEY_Arabic_kasra                = uint(C.GDK_KEY_Arabic_kasra)
	KEY_Arabic_shadda               = uint(C.GDK_KEY_Arabic_shadda)
	KEY_Arabic_sukun                = uint(C.GDK_KEY_Arabic_sukun)
	KEY_Arabic_madda_above          = uint(C.GDK_KEY_Arabic_madda_above)
	KEY_Arabic_hamza_above          = uint(C.GDK_KEY_Arabic_hamza_above)
	KEY_Arabic_hamza_below          = uint(C.GDK_KEY_Arabic_hamza_below)
	KEY_Arabic_jeh                  = uint(C.GDK_KEY_Arabic_jeh)
	KEY_Arabic_veh                  = uint(C.GDK_KEY_Arabic_veh)
	KEY_Arabic_keheh                = uint(C.GDK_KEY_Arabic_keheh)
	KEY_Arabic_gaf                  = uint(C.GDK_KEY_Arabic_gaf)
	KEY_Arabic_noon_ghunna          = uint(C.GDK_KEY_Arabic_noon_ghunna)
	KEY_Arabic_heh_doachashmee      = uint(C.GDK_KEY_Arabic_heh_doachashmee)
	KEY_Farsi_yeh                   = uint(C.GDK_KEY_Farsi_yeh)
	KEY_Arabic_farsi_yeh            = uint(C.GDK_KEY_Arabic_farsi_yeh)
	KEY_Arabic_yeh_baree            = uint(C.GDK_KEY_Arabic_yeh_baree)
	KEY_Arabic_heh_goal             = uint(C.GDK_KEY_Arabic_heh_goal)
	KEY_Arabic_switch               = uint(C.GDK_KEY_Arabic_switch)
	KEY_Cyrillic_GHE_bar            = uint(C.GDK_KEY_Cyrillic_GHE_bar)
	KEY_Cyrillic_ghe_bar            = uint(C.GDK_KEY_Cyrillic_ghe_bar)
	KEY_Cyrillic_ZHE_descender      = uint(C.GDK_KEY_Cyrillic_ZHE_descender)
	KEY_Cyrillic_zhe_descender      = uint(C.GDK_KEY_Cyrillic_zhe_descender)
	KEY_Cyrillic_KA_descender       = uint(C.GDK_KEY_Cyrillic_KA_descender)
	KEY_Cyrillic_ka_descender       = uint(C.GDK_KEY_Cyrillic_ka_descender)
	KEY_Cyrillic_KA_vertstroke      = uint(C.GDK_KEY_Cyrillic_KA_vertstroke)
	KEY_Cyrillic_ka_vertstroke      = uint(C.GDK_KEY_Cyrillic_ka_vertstroke)
	KEY_Cyrillic_EN_descender       = uint(C.GDK_KEY_Cyrillic_EN_descender)
	KEY_Cyrillic_en_descender       = uint(C.GDK_KEY_Cyrillic_en_descender)
	KEY_Cyrillic_U_straight         = uint(C.GDK_KEY_Cyrillic_U_straight)
	KEY_Cyrillic_u_straight         = uint(C.GDK_KEY_Cyrillic_u_straight)
	KEY_Cyrillic_U_straight_bar     = uint(C.GDK_KEY_Cyrillic_U_straight_bar)
	KEY_Cyrillic_u_straight_bar     = uint(C.GDK_KEY_Cyrillic_u_straight_bar)
	KEY_Cyrillic_HA_descender       = uint(C.GDK_KEY_Cyrillic_HA_descender)
	KEY_Cyrillic_ha_descender       = uint(C.GDK_KEY_Cyrillic_ha_descender)
	KEY_Cyrillic_CHE_descender      = uint(C.GDK_KEY_Cyrillic_CHE_descender)
	KEY_Cyrillic_che_descender      = uint(C.GDK_KEY_Cyrillic_che_descender)
	KEY_Cyrillic_CHE_vertstroke     = uint(C.GDK_KEY_Cyrillic_CHE_vertstroke)
	KEY_Cyrillic_che_vertstroke     = uint(C.GDK_KEY_Cyrillic_che_vertstroke)
	KEY_Cyrillic_SHHA               = uint(C.GDK_KEY_Cyrillic_SHHA)
	KEY_Cyrillic_shha               = uint(C.GDK_KEY_Cyrillic_shha)
	KEY_Cyrillic_SCHWA              = uint(C.GDK_KEY_Cyrillic_SCHWA)
	KEY_Cyrillic_schwa              = uint(C.GDK_KEY_Cyrillic_schwa)
	KEY_Cyrillic_I_macron           = uint(C.GDK_KEY_Cyrillic_I_macron)
	KEY_Cyrillic_i_macron           = uint(C.GDK_KEY_Cyrillic_i_macron)
	KEY_Cyrillic_O_bar              = uint(C.GDK_KEY_Cyrillic_O_bar)
	KEY_Cyrillic_o_bar              = uint(C.GDK_KEY_Cyrillic_o_bar)
	KEY_Cyrillic_U_macron           = uint(C.GDK_KEY_Cyrillic_U_macron)
	KEY_Cyrillic_u_macron           = uint(C.GDK_KEY_Cyrillic_u_macron)
	KEY_Serbian_dje                 = uint(C.GDK_KEY_Serbian_dje)
	KEY_Macedonia_gje               = uint(C.GDK_KEY_Macedonia_gje)
	KEY_Cyrillic_io                 = uint(C.GDK_KEY_Cyrillic_io)
	KEY_Ukrainian_ie                = uint(C.GDK_KEY_Ukrainian_ie)
	KEY_Ukranian_je                 = uint(C.GDK_KEY_Ukranian_je)
	KEY_Macedonia_dse               = uint(C.GDK_KEY_Macedonia_dse)
	KEY_Ukrainian_i                 = uint(C.GDK_KEY_Ukrainian_i)
	KEY_Ukranian_i                  = uint(C.GDK_KEY_Ukranian_i)
	KEY_Ukrainian_yi                = uint(C.GDK_KEY_Ukrainian_yi)
	KEY_Ukranian_yi                 = uint(C.GDK_KEY_Ukranian_yi)
	KEY_Cyrillic_je                 = uint(C.GDK_KEY_Cyrillic_je)
	KEY_Serbian_je                  = uint(C.GDK_KEY_Serbian_je)
	KEY_Cyrillic_lje                = uint(C.GDK_KEY_Cyrillic_lje)
	KEY_Serbian_lje                 = uint(C.GDK_KEY_Serbian_lje)
	KEY_Cyrillic_nje                = uint(C.GDK_KEY_Cyrillic_nje)
	KEY_Serbian_nje                 = uint(C.GDK_KEY_Serbian_nje)
	KEY_Serbian_tshe                = uint(C.GDK_KEY_Serbian_tshe)
	KEY_Macedonia_kje               = uint(C.GDK_KEY_Macedonia_kje)
	KEY_Ukrainian_ghe_with_upturn   = uint(C.GDK_KEY_Ukrainian_ghe_with_upturn)
	KEY_Byelorussian_shortu         = uint(C.GDK_KEY_Byelorussian_shortu)
	KEY_Cyrillic_dzhe               = uint(C.GDK_KEY_Cyrillic_dzhe)
	KEY_Serbian_dze                 = uint(C.GDK_KEY_Serbian_dze)
	KEY_numerosign                  = uint(C.GDK_KEY_numerosign)
	KEY_Serbian_DJE                 = uint(C.GDK_KEY_Serbian_DJE)
	KEY_Macedonia_GJE               = uint(C.GDK_KEY_Macedonia_GJE)
	KEY_Cyrillic_IO                 = uint(C.GDK_KEY_Cyrillic_IO)
	KEY_Ukrainian_IE                = uint(C.GDK_KEY_Ukrainian_IE)
	KEY_Ukranian_JE                 = uint(C.GDK_KEY_Ukranian_JE)
	KEY_Macedonia_DSE               = uint(C.GDK_KEY_Macedonia_DSE)
	KEY_Ukrainian_I                 = uint(C.GDK_KEY_Ukrainian_I)
	KEY_Ukranian_I                  = uint(C.GDK_KEY_Ukranian_I)
	KEY_Ukrainian_YI                = uint(C.GDK_KEY_Ukrainian_YI)
	KEY_Ukranian_YI                 = uint(C.GDK_KEY_Ukranian_YI)
	KEY_Cyrillic_JE                 = uint(C.GDK_KEY_Cyrillic_JE)
	KEY_Serbian_JE                  = uint(C.GDK_KEY_Serbian_JE)
	KEY_Cyrillic_LJE                = uint(C.GDK_KEY_Cyrillic_LJE)
	KEY_Serbian_LJE                 = uint(C.GDK_KEY_Serbian_LJE)
	KEY_Cyrillic_NJE                = uint(C.GDK_KEY_Cyrillic_NJE)
	KEY_Serbian_NJE                 = uint(C.GDK_KEY_Serbian_NJE)
	KEY_Serbian_TSHE                = uint(C.GDK_KEY_Serbian_TSHE)
	KEY_Macedonia_KJE               = uint(C.GDK_KEY_Macedonia_KJE)
	KEY_Ukrainian_GHE_WITH_UPTURN   = uint(C.GDK_KEY_Ukrainian_GHE_WITH_UPTURN)
	KEY_Byelorussian_SHORTU         = uint(C.GDK_KEY_Byelorussian_SHORTU)
	KEY_Cyrillic_DZHE               = uint(C.GDK_KEY_Cyrillic_DZHE)
	KEY_Serbian_DZE                 = uint(C.GDK_KEY_Serbian_DZE)
	KEY_Cyrillic_yu                 = uint(C.GDK_KEY_Cyrillic_yu)
	KEY_Cyrillic_a                  = uint(C.GDK_KEY_Cyrillic_a)
	KEY_Cyrillic_be                 = uint(C.GDK_KEY_Cyrillic_be)
	KEY_Cyrillic_tse                = uint(C.GDK_KEY_Cyrillic_tse)
	KEY_Cyrillic_de                 = uint(C.GDK_KEY_Cyrillic_de)
	KEY_Cyrillic_ie                 = uint(C.GDK_KEY_Cyrillic_ie)
	KEY_Cyrillic_ef                 = uint(C.GDK_KEY_Cyrillic_ef)
	KEY_Cyrillic_ghe                = uint(C.GDK_KEY_Cyrillic_ghe)
	KEY_Cyrillic_ha                 = uint(C.GDK_KEY_Cyrillic_ha)
	KEY_Cyrillic_i                  = uint(C.GDK_KEY_Cyrillic_i)
	KEY_Cyrillic_shorti             = uint(C.GDK_KEY_Cyrillic_shorti)
	KEY_Cyrillic_ka                 = uint(C.GDK_KEY_Cyrillic_ka)
	KEY_Cyrillic_el                 = uint(C.GDK_KEY_Cyrillic_el)
	KEY_Cyrillic_em                 = uint(C.GDK_KEY_Cyrillic_em)
	KEY_Cyrillic_en                 = uint(C.GDK_KEY_Cyrillic_en)
	KEY_Cyrillic_o                  = uint(C.GDK_KEY_Cyrillic_o)
	KEY_Cyrillic_pe                 = uint(C.GDK_KEY_Cyrillic_pe)
	KEY_Cyrillic_ya                 = uint(C.GDK_KEY_Cyrillic_ya)
	KEY_Cyrillic_er                 = uint(C.GDK_KEY_Cyrillic_er)
	KEY_Cyrillic_es                 = uint(C.GDK_KEY_Cyrillic_es)
	KEY_Cyrillic_te                 = uint(C.GDK_KEY_Cyrillic_te)
	KEY_Cyrillic_u                  = uint(C.GDK_KEY_Cyrillic_u)
	KEY_Cyrillic_zhe                = uint(C.GDK_KEY_Cyrillic_zhe)
	KEY_Cyrillic_ve                 = uint(C.GDK_KEY_Cyrillic_ve)
	KEY_Cyrillic_softsign           = uint(C.GDK_KEY_Cyrillic_softsign)
	KEY_Cyrillic_yeru               = uint(C.GDK_KEY_Cyrillic_yeru)
	KEY_Cyrillic_ze                 = uint(C.GDK_KEY_Cyrillic_ze)
	KEY_Cyrillic_sha                = uint(C.GDK_KEY_Cyrillic_sha)
	KEY_Cyrillic_e                  = uint(C.GDK_KEY_Cyrillic_e)
	KEY_Cyrillic_shcha              = uint(C.GDK_KEY_Cyrillic_shcha)
	KEY_Cyrillic_che                = uint(C.GDK_KEY_Cyrillic_che)
	KEY_Cyrillic_hardsign           = uint(C.GDK_KEY_Cyrillic_hardsign)
	KEY_Cyrillic_YU                 = uint(C.GDK_KEY_Cyrillic_YU)
	KEY_Cyrillic_A                  = uint(C.GDK_KEY_Cyrillic_A)
	KEY_Cyrillic_BE                 = uint(C.GDK_KEY_Cyrillic_BE)
	KEY_Cyrillic_TSE                = uint(C.GDK_KEY_Cyrillic_TSE)
	KEY_Cyrillic_DE                 = uint(C.GDK_KEY_Cyrillic_DE)
	KEY_Cyrillic_IE                 = uint(C.GDK_KEY_Cyrillic_IE)
	KEY_Cyrillic_EF                 = uint(C.GDK_KEY_Cyrillic_EF)
	KEY_Cyrillic_GHE                = uint(C.GDK_KEY_Cyrillic_GHE)
	KEY_Cyrillic_HA                 = uint(C.GDK_KEY_Cyrillic_HA)
	KEY_Cyrillic_I                  = uint(C.GDK_KEY_Cyrillic_I)
	KEY_Cyrillic_SHORTI             = uint(C.GDK_KEY_Cyrillic_SHORTI)
	KEY_Cyrillic_KA                 = uint(C.GDK_KEY_Cyrillic_KA)
	KEY_Cyrillic_EL                 = uint(C.GDK_KEY_Cyrillic_EL)
	KEY_Cyrillic_EM                 = uint(C.GDK_KEY_Cyrillic_EM)
	KEY_Cyrillic_EN                 = uint(C.GDK_KEY_Cyrillic_EN)
	KEY_Cyrillic_O                  = uint(C.GDK_KEY_Cyrillic_O)
	KEY_Cyrillic_PE                 = uint(C.GDK_KEY_Cyrillic_PE)
	KEY_Cyrillic_YA                 = uint(C.GDK_KEY_Cyrillic_YA)
	KEY_Cyrillic_ER                 = uint(C.GDK_KEY_Cyrillic_ER)
	KEY_Cyrillic_ES                 = uint(C.GDK_KEY_Cyrillic_ES)
	KEY_Cyrillic_TE                 = uint(C.GDK_KEY_Cyrillic_TE)
	KEY_Cyrillic_U                  = uint(C.GDK_KEY_Cyrillic_U)
	KEY_Cyrillic_ZHE                = uint(C.GDK_KEY_Cyrillic_ZHE)
	KEY_Cyrillic_VE                 = uint(C.GDK_KEY_Cyrillic_VE)
	KEY_Cyrillic_SOFTSIGN           = uint(C.GDK_KEY_Cyrillic_SOFTSIGN)
	KEY_Cyrillic_YERU               = uint(C.GDK_KEY_Cyrillic_YERU)
	KEY_Cyrillic_ZE                 = uint(C.GDK_KEY_Cyrillic_ZE)
	KEY_Cyrillic_SHA                = uint(C.GDK_KEY_Cyrillic_SHA)
	KEY_Cyrillic_E                  = uint(C.GDK_KEY_Cyrillic_E)
	KEY_Cyrillic_SHCHA              = uint(C.GDK_KEY_Cyrillic_SHCHA)
	KEY_Cyrillic_CHE                = uint(C.GDK_KEY_Cyrillic_CHE)
	KEY_Cyrillic_HARDSIGN           = uint(C.GDK_KEY_Cyrillic_HARDSIGN)
	KEY_Greek_ALPHAaccent           = uint(C.GDK_KEY_Greek_ALPHAaccent)
	KEY_Greek_EPSILONaccent         = uint(C.GDK_KEY_Greek_EPSILONaccent)
	KEY_Greek_ETAaccent             = uint(C.GDK_KEY_Greek_ETAaccent)
	KEY_Greek_IOTAaccent            = uint(C.GDK_KEY_Greek_IOTAaccent)
	KEY_Greek_IOTAdieresis          = uint(C.GDK_KEY_Greek_IOTAdieresis)
	KEY_Greek_IOTAdiaeresis         = uint(C.GDK_KEY_Greek_IOTAdiaeresis)
	KEY_Greek_OMICRONaccent         = uint(C.GDK_KEY_Greek_OMICRONaccent)
	KEY_Greek_UPSILONaccent         = uint(C.GDK_KEY_Greek_UPSILONaccent)
	KEY_Greek_UPSILONdieresis       = uint(C.GDK_KEY_Greek_UPSILONdieresis)
	KEY_Greek_OMEGAaccent           = uint(C.GDK_KEY_Greek_OMEGAaccent)
	KEY_Greek_accentdieresis        = uint(C.GDK_KEY_Greek_accentdieresis)
	KEY_Greek_horizbar              = uint(C.GDK_KEY_Greek_horizbar)
	KEY_Greek_alphaaccent           = uint(C.GDK_KEY_Greek_alphaaccent)
	KEY_Greek_epsilonaccent         = uint(C.GDK_KEY_Greek_epsilonaccent)
	KEY_Greek_etaaccent             = uint(C.GDK_KEY_Greek_etaaccent)
	KEY_Greek_iotaaccent            = uint(C.GDK_KEY_Greek_iotaaccent)
	KEY_Greek_iotadieresis          = uint(C.GDK_KEY_Greek_iotadieresis)
	KEY_Greek_iotaaccentdieresis    = uint(C.GDK_KEY_Greek_iotaaccentdieresis)
	KEY_Greek_omicronaccent         = uint(C.GDK_KEY_Greek_omicronaccent)
	KEY_Greek_upsilonaccent         = uint(C.GDK_KEY_Greek_upsilonaccent)
	KEY_Greek_upsilondieresis       = uint(C.GDK_KEY_Greek_upsilondieresis)
	KEY_Greek_upsilonaccentdieresis = uint(C.GDK_KEY_Greek_upsilonaccentdieresis)
	KEY_Greek_omegaaccent           = uint(C.GDK_KEY_Greek_omegaaccent)
	KEY_Greek_ALPHA                 = uint(C.GDK_KEY_Greek_ALPHA)
	KEY_Greek_BETA                  = uint(C.GDK_KEY_Greek_BETA)
	KEY_Greek_GAMMA                 = uint(C.GDK_KEY_Greek_GAMMA)
	KEY_Greek_DELTA                 = uint(C.GDK_KEY_Greek_DELTA)
	KEY_Greek_EPSILON               = uint(C.GDK_KEY_Greek_EPSILON)
	KEY_Greek_ZETA                  = uint(C.GDK_KEY_Greek_ZETA)
	KEY_Greek_ETA                   = uint(C.GDK_KEY_Greek_ETA)
	KEY_Greek_THETA                 = uint(C.GDK_KEY_Greek_THETA)
	KEY_Greek_IOTA                  = uint(C.GDK_KEY_Greek_IOTA)
	KEY_Greek_KAPPA                 = uint(C.GDK_KEY_Greek_KAPPA)
	KEY_Greek_LAMDA                 = uint(C.GDK_KEY_Greek_LAMDA)
	KEY_Greek_LAMBDA                = uint(C.GDK_KEY_Greek_LAMBDA)
	KEY_Greek_MU                    = uint(C.GDK_KEY_Greek_MU)
	KEY_Greek_NU                    = uint(C.GDK_KEY_Greek_NU)
	KEY_Greek_XI                    = uint(C.GDK_KEY_Greek_XI)
	KEY_Greek_OMICRON               = uint(C.GDK_KEY_Greek_OMICRON)
	KEY_Greek_PI                    = uint(C.GDK_KEY_Greek_PI)
	KEY_Greek_RHO                   = uint(C.GDK_KEY_Greek_RHO)
	KEY_Greek_SIGMA                 = uint(C.GDK_KEY_Greek_SIGMA)
	KEY_Greek_TAU                   = uint(C.GDK_KEY_Greek_TAU)
	KEY_Greek_UPSILON               = uint(C.GDK_KEY_Greek_UPSILON)
	KEY_Greek_PHI                   = uint(C.GDK_KEY_Greek_PHI)
	KEY_Greek_CHI                   = uint(C.GDK_KEY_Greek_CHI)
	KEY_Greek_PSI                   = uint(C.GDK_KEY_Greek_PSI)
	KEY_Greek_OMEGA                 = uint(C.GDK_KEY_Greek_OMEGA)
	KEY_Greek_alpha                 = uint(C.GDK_KEY_Greek_alpha)
	KEY_Greek_beta                  = uint(C.GDK_KEY_Greek_beta)
	KEY_Greek_gamma                 = uint(C.GDK_KEY_Greek_gamma)
	KEY_Greek_delta                 = uint(C.GDK_KEY_Greek_delta)
	KEY_Greek_epsilon               = uint(C.GDK_KEY_Greek_epsilon)
	KEY_Greek_zeta                  = uint(C.GDK_KEY_Greek_zeta)
	KEY_Greek_eta                   = uint(C.GDK_KEY_Greek_eta)
	KEY_Greek_theta                 = uint(C.GDK_KEY_Greek_theta)
	KEY_Greek_iota                  = uint(C.GDK_KEY_Greek_iota)
	KEY_Greek_kappa                 = uint(C.GDK_KEY_Greek_kappa)
	KEY_Greek_lamda                 = uint(C.GDK_KEY_Greek_lamda)
	KEY_Greek_lambda                = uint(C.GDK_KEY_Greek_lambda)
	KEY_Greek_mu                    = uint(C.GDK_KEY_Greek_mu)
	KEY_Greek_nu                    = uint(C.GDK_KEY_Greek_nu)
	KEY_Greek_xi                    = uint(C.GDK_KEY_Greek_xi)
	KEY_Greek_omicron               = uint(C.GDK_KEY_Greek_omicron)
	KEY_Greek_pi                    = uint(C.GDK_KEY_Greek_pi)
	KEY_Greek_rho                   = uint(C.GDK_KEY_Greek_rho)
	KEY_Greek_sigma                 = uint(C.GDK_KEY_Greek_sigma)
	KEY_Greek_finalsmallsigma       = uint(C.GDK_KEY_Greek_finalsmallsigma)
	KEY_Greek_tau                   = uint(C.GDK_KEY_Greek_tau)
	KEY_Greek_upsilon               = uint(C.GDK_KEY_Greek_upsilon)
	KEY_Greek_phi                   = uint(C.GDK_KEY_Greek_phi)
	KEY_Greek_chi                   = uint(C.GDK_KEY_Greek_chi)
	KEY_Greek_psi                   = uint(C.GDK_KEY_Greek_psi)
	KEY_Greek_omega                 = uint(C.GDK_KEY_Greek_omega)
	KEY_Greek_switch                = uint(C.GDK_KEY_Greek_switch)
	KEY_leftradical                 = uint(C.GDK_KEY_leftradical)
	KEY_topleftradical              = uint(C.GDK_KEY_topleftradical)
	KEY_horizconnector              = uint(C.GDK_KEY_horizconnector)
	KEY_topintegral                 = uint(C.GDK_KEY_topintegral)
	KEY_botintegral                 = uint(C.GDK_KEY_botintegral)
	KEY_vertconnector               = uint(C.GDK_KEY_vertconnector)
	KEY_topleftsqbracket            = uint(C.GDK_KEY_topleftsqbracket)
	KEY_botleftsqbracket            = uint(C.GDK_KEY_botleftsqbracket)
	KEY_toprightsqbracket           = uint(C.GDK_KEY_toprightsqbracket)
	KEY_botrightsqbracket           = uint(C.GDK_KEY_botrightsqbracket)
	KEY_topleftparens               = uint(C.GDK_KEY_topleftparens)
	KEY_botleftparens               = uint(C.GDK_KEY_botleftparens)
	KEY_toprightparens              = uint(C.GDK_KEY_toprightparens)
	KEY_botrightparens              = uint(C.GDK_KEY_botrightparens)
	KEY_leftmiddlecurlybrace        = uint(C.GDK_KEY_leftmiddlecurlybrace)
	KEY_rightmiddlecurlybrace       = uint(C.GDK_KEY_rightmiddlecurlybrace)
	KEY_topleftsummation            = uint(C.GDK_KEY_topleftsummation)
	KEY_botleftsummation            = uint(C.GDK_KEY_botleftsummation)
	KEY_topvertsummationconnector   = uint(C.GDK_KEY_topvertsummationconnector)
	KEY_botvertsummationconnector   = uint(C.GDK_KEY_botvertsummationconnector)
	KEY_toprightsummation           = uint(C.GDK_KEY_toprightsummation)
	KEY_botrightsummation           = uint(C.GDK_KEY_botrightsummation)
	KEY_rightmiddlesummation        = uint(C.GDK_KEY_rightmiddlesummation)
	KEY_lessthanequal               = uint(C.GDK_KEY_lessthanequal)
	KEY_notequal                    = uint(C.GDK_KEY_notequal)
	KEY_greaterthanequal            = uint(C.GDK_KEY_greaterthanequal)
	KEY_integral                    = uint(C.GDK_KEY_integral)
	KEY_therefore                   = uint(C.GDK_KEY_therefore)
	KEY_variation                   = uint(C.GDK_KEY_variation)
	KEY_infinity                    = uint(C.GDK_KEY_infinity)
	KEY_nabla                       = uint(C.GDK_KEY_nabla)
	KEY_approximate                 = uint(C.GDK_KEY_approximate)
	KEY_similarequal                = uint(C.GDK_KEY_similarequal)
	KEY_ifonlyif                    = uint(C.GDK_KEY_ifonlyif)
	KEY_implies                     = uint(C.GDK_KEY_implies)
	KEY_identical                   = uint(C.GDK_KEY_identical)
	KEY_radical                     = uint(C.GDK_KEY_radical)
	KEY_includedin                  = uint(C.GDK_KEY_includedin)
	KEY_includes                    = uint(C.GDK_KEY_includes)
	KEY_intersection                = uint(C.GDK_KEY_intersection)
	KEY_union                       = uint(C.GDK_KEY_union)
	KEY_logicaland                  = uint(C.GDK_KEY_logicaland)
	KEY_logicalor                   = uint(C.GDK_KEY_logicalor)
	KEY_partialderivative           = uint(C.GDK_KEY_partialderivative)
	KEY_function                    = uint(C.GDK_KEY_function)
	KEY_leftarrow                   = uint(C.GDK_KEY_leftarrow)
	KEY_uparrow                     = uint(C.GDK_KEY_uparrow)
	KEY_rightarrow                  = uint(C.GDK_KEY_rightarrow)
	KEY_downarrow                   = uint(C.GDK_KEY_downarrow)
	KEY_blank                       = uint(C.GDK_KEY_blank)
	KEY_soliddiamond                = uint(C.GDK_KEY_soliddiamond)
	KEY_checkerboard                = uint(C.GDK_KEY_checkerboard)
	KEY_ht                          = uint(C.GDK_KEY_ht)
	KEY_ff                          = uint(C.GDK_KEY_ff)
	KEY_cr                          = uint(C.GDK_KEY_cr)
	KEY_lf                          = uint(C.GDK_KEY_lf)
	KEY_nl                          = uint(C.GDK_KEY_nl)
	KEY_vt                          = uint(C.GDK_KEY_vt)
	KEY_lowrightcorner              = uint(C.GDK_KEY_lowrightcorner)
	KEY_uprightcorner               = uint(C.GDK_KEY_uprightcorner)
	KEY_upleftcorner                = uint(C.GDK_KEY_upleftcorner)
	KEY_lowleftcorner               = uint(C.GDK_KEY_lowleftcorner)
	KEY_crossinglines               = uint(C.GDK_KEY_crossinglines)
	KEY_horizlinescan1              = uint(C.GDK_KEY_horizlinescan1)
	KEY_horizlinescan3              = uint(C.GDK_KEY_horizlinescan3)
	KEY_horizlinescan5              = uint(C.GDK_KEY_horizlinescan5)
	KEY_horizlinescan7              = uint(C.GDK_KEY_horizlinescan7)
	KEY_horizlinescan9              = uint(C.GDK_KEY_horizlinescan9)
	KEY_leftt                       = uint(C.GDK_KEY_leftt)
	KEY_rightt                      = uint(C.GDK_KEY_rightt)
	KEY_bott                        = uint(C.GDK_KEY_bott)
	KEY_topt                        = uint(C.GDK_KEY_topt)
	KEY_vertbar                     = uint(C.GDK_KEY_vertbar)
	KEY_emspace                     = uint(C.GDK_KEY_emspace)
	KEY_enspace                     = uint(C.GDK_KEY_enspace)
	KEY_em3space                    = uint(C.GDK_KEY_em3space)
	KEY_em4space                    = uint(C.GDK_KEY_em4space)
	KEY_digitspace                  = uint(C.GDK_KEY_digitspace)
	KEY_punctspace                  = uint(C.GDK_KEY_punctspace)
	KEY_thinspace                   = uint(C.GDK_KEY_thinspace)
	KEY_hairspace                   = uint(C.GDK_KEY_hairspace)
	KEY_emdash                      = uint(C.GDK_KEY_emdash)
	KEY_endash                      = uint(C.GDK_KEY_endash)
	KEY_signifblank                 = uint(C.GDK_KEY_signifblank)
	KEY_ellipsis                    = uint(C.GDK_KEY_ellipsis)
	KEY_doubbaselinedot             = uint(C.GDK_KEY_doubbaselinedot)
	KEY_onethird                    = uint(C.GDK_KEY_onethird)
	KEY_twothirds                   = uint(C.GDK_KEY_twothirds)
	KEY_onefifth                    = uint(C.GDK_KEY_onefifth)
	KEY_twofifths                   = uint(C.GDK_KEY_twofifths)
	KEY_threefifths                 = uint(C.GDK_KEY_threefifths)
	KEY_fourfifths                  = uint(C.GDK_KEY_fourfifths)
	KEY_onesixth                    = uint(C.GDK_KEY_onesixth)
	KEY_fivesixths                  = uint(C.GDK_KEY_fivesixths)
	KEY_careof                      = uint(C.GDK_KEY_careof)
	KEY_figdash                     = uint(C.GDK_KEY_figdash)
	KEY_leftanglebracket            = uint(C.GDK_KEY_leftanglebracket)
	KEY_decimalpoint                = uint(C.GDK_KEY_decimalpoint)
	KEY_rightanglebracket           = uint(C.GDK_KEY_rightanglebracket)
	KEY_marker                      = uint(C.GDK_KEY_marker)
	KEY_oneeighth                   = uint(C.GDK_KEY_oneeighth)
	KEY_threeeighths                = uint(C.GDK_KEY_threeeighths)
	KEY_fiveeighths                 = uint(C.GDK_KEY_fiveeighths)
	KEY_seveneighths                = uint(C.GDK_KEY_seveneighths)
	KEY_trademark                   = uint(C.GDK_KEY_trademark)
	KEY_signaturemark               = uint(C.GDK_KEY_signaturemark)
	KEY_trademarkincircle           = uint(C.GDK_KEY_trademarkincircle)
	KEY_leftopentriangle            = uint(C.GDK_KEY_leftopentriangle)
	KEY_rightopentriangle           = uint(C.GDK_KEY_rightopentriangle)
	KEY_emopencircle                = uint(C.GDK_KEY_emopencircle)
	KEY_emopenrectangle             = uint(C.GDK_KEY_emopenrectangle)
	KEY_leftsinglequotemark         = uint(C.GDK_KEY_leftsinglequotemark)
	KEY_rightsinglequotemark        = uint(C.GDK_KEY_rightsinglequotemark)
	KEY_leftdoublequotemark         = uint(C.GDK_KEY_leftdoublequotemark)
	KEY_rightdoublequotemark        = uint(C.GDK_KEY_rightdoublequotemark)
	KEY_prescription                = uint(C.GDK_KEY_prescription)
	KEY_permille                    = uint(C.GDK_KEY_permille)
	KEY_minutes                     = uint(C.GDK_KEY_minutes)
	KEY_seconds                     = uint(C.GDK_KEY_seconds)
	KEY_latincross                  = uint(C.GDK_KEY_latincross)
	KEY_hexagram                    = uint(C.GDK_KEY_hexagram)
	KEY_filledrectbullet            = uint(C.GDK_KEY_filledrectbullet)
	KEY_filledlefttribullet         = uint(C.GDK_KEY_filledlefttribullet)
	KEY_filledrighttribullet        = uint(C.GDK_KEY_filledrighttribullet)
	KEY_emfilledcircle              = uint(C.GDK_KEY_emfilledcircle)
	KEY_emfilledrect                = uint(C.GDK_KEY_emfilledrect)
	KEY_enopencircbullet            = uint(C.GDK_KEY_enopencircbullet)
	KEY_enopensquarebullet          = uint(C.GDK_KEY_enopensquarebullet)
	KEY_openrectbullet              = uint(C.GDK_KEY_openrectbullet)
	KEY_opentribulletup             = uint(C.GDK_KEY_opentribulletup)
	KEY_opentribulletdown           = uint(C.GDK_KEY_opentribulletdown)
	KEY_openstar                    = uint(C.GDK_KEY_openstar)
	KEY_enfilledcircbullet          = uint(C.GDK_KEY_enfilledcircbullet)
	KEY_enfilledsqbullet            = uint(C.GDK_KEY_enfilledsqbullet)
	KEY_filledtribulletup           = uint(C.GDK_KEY_filledtribulletup)
	KEY_filledtribulletdown         = uint(C.GDK_KEY_filledtribulletdown)
	KEY_leftpointer                 = uint(C.GDK_KEY_leftpointer)
	KEY_rightpointer                = uint(C.GDK_KEY_rightpointer)
	KEY_club                        = uint(C.GDK_KEY_club)
	KEY_diamond                     = uint(C.GDK_KEY_diamond)
	KEY_heart                       = uint(C.GDK_KEY_heart)
	KEY_maltesecross                = uint(C.GDK_KEY_maltesecross)
	KEY_dagger                      = uint(C.GDK_KEY_dagger)
	KEY_doubledagger                = uint(C.GDK_KEY_doubledagger)
	KEY_checkmark                   = uint(C.GDK_KEY_checkmark)
	KEY_ballotcross                 = uint(C.GDK_KEY_ballotcross)
	KEY_musicalsharp                = uint(C.GDK_KEY_musicalsharp)
	KEY_musicalflat                 = uint(C.GDK_KEY_musicalflat)
	KEY_malesymbol                  = uint(C.GDK_KEY_malesymbol)
	KEY_femalesymbol                = uint(C.GDK_KEY_femalesymbol)
	KEY_telephone                   = uint(C.GDK_KEY_telephone)
	KEY_telephonerecorder           = uint(C.GDK_KEY_telephonerecorder)
	KEY_phonographcopyright         = uint(C.GDK_KEY_phonographcopyright)
	KEY_caret                       = uint(C.GDK_KEY_caret)
	KEY_singlelowquotemark          = uint(C.GDK_KEY_singlelowquotemark)
	KEY_doublelowquotemark          = uint(C.GDK_KEY_doublelowquotemark)
	KEY_cursor                      = uint(C.GDK_KEY_cursor)
	KEY_leftcaret                   = uint(C.GDK_KEY_leftcaret)
	KEY_rightcaret                  = uint(C.GDK_KEY_rightcaret)
	KEY_downcaret                   = uint(C.GDK_KEY_downcaret)
	KEY_upcaret                     = uint(C.GDK_KEY_upcaret)
	KEY_overbar                     = uint(C.GDK_KEY_overbar)
	KEY_downtack                    = uint(C.GDK_KEY_downtack)
	KEY_upshoe                      = uint(C.GDK_KEY_upshoe)
	KEY_downstile                   = uint(C.GDK_KEY_downstile)
	KEY_underbar                    = uint(C.GDK_KEY_underbar)
	KEY_jot                         = uint(C.GDK_KEY_jot)
	KEY_quad                        = uint(C.GDK_KEY_quad)
	KEY_uptack                      = uint(C.GDK_KEY_uptack)
	KEY_circle                      = uint(C.GDK_KEY_circle)
	KEY_upstile                     = uint(C.GDK_KEY_upstile)
	KEY_downshoe                    = uint(C.GDK_KEY_downshoe)
	KEY_rightshoe                   = uint(C.GDK_KEY_rightshoe)
	KEY_leftshoe                    = uint(C.GDK_KEY_leftshoe)
	KEY_lefttack                    = uint(C.GDK_KEY_lefttack)
	KEY_righttack                   = uint(C.GDK_KEY_righttack)
	KEY_hebrew_doublelowline        = uint(C.GDK_KEY_hebrew_doublelowline)
	KEY_hebrew_aleph                = uint(C.GDK_KEY_hebrew_aleph)
	KEY_hebrew_bet                  = uint(C.GDK_KEY_hebrew_bet)
	KEY_hebrew_beth                 = uint(C.GDK_KEY_hebrew_beth)
	KEY_hebrew_gimel                = uint(C.GDK_KEY_hebrew_gimel)
	KEY_hebrew_gimmel               = uint(C.GDK_KEY_hebrew_gimmel)
	KEY_hebrew_dalet                = uint(C.GDK_KEY_hebrew_dalet)
	KEY_hebrew_daleth               = uint(C.GDK_KEY_hebrew_daleth)
	KEY_hebrew_he                   = uint(C.GDK_KEY_hebrew_he)
	KEY_hebrew_waw                  = uint(C.GDK_KEY_hebrew_waw)
	KEY_hebrew_zain                 = uint(C.GDK_KEY_hebrew_zain)
	KEY_hebrew_zayin                = uint(C.GDK_KEY_hebrew_zayin)
	KEY_hebrew_chet                 = uint(C.GDK_KEY_hebrew_chet)
	KEY_hebrew_het                  = uint(C.GDK_KEY_hebrew_het)
	KEY_hebrew_tet                  = uint(C.GDK_KEY_hebrew_tet)
	KEY_hebrew_teth                 = uint(C.GDK_KEY_hebrew_teth)
	KEY_hebrew_yod                  = uint(C.GDK_KEY_hebrew_yod)
	KEY_hebrew_finalkaph            = uint(C.GDK_KEY_hebrew_finalkaph)
	KEY_hebrew_kaph                 = uint(C.GDK_KEY_hebrew_kaph)
	KEY_hebrew_lamed                = uint(C.GDK_KEY_hebrew_lamed)
	KEY_hebrew_finalmem             = uint(C.GDK_KEY_hebrew_finalmem)
	KEY_hebrew_mem                  = uint(C.GDK_KEY_hebrew_mem)
	KEY_hebrew_finalnun             = uint(C.GDK_KEY_hebrew_finalnun)
	KEY_hebrew_nun                  = uint(C.GDK_KEY_hebrew_nun)
	KEY_hebrew_samech               = uint(C.GDK_KEY_hebrew_samech)
	KEY_hebrew_samekh               = uint(C.GDK_KEY_hebrew_samekh)
	KEY_hebrew_ayin                 = uint(C.GDK_KEY_hebrew_ayin)
	KEY_hebrew_finalpe              = uint(C.GDK_KEY_hebrew_finalpe)
	KEY_hebrew_pe                   = uint(C.GDK_KEY_hebrew_pe)
	KEY_hebrew_finalzade            = uint(C.GDK_KEY_hebrew_finalzade)
	KEY_hebrew_finalzadi            = uint(C.GDK_KEY_hebrew_finalzadi)
	KEY_hebrew_zade                 = uint(C.GDK_KEY_hebrew_zade)
	KEY_hebrew_zadi                 = uint(C.GDK_KEY_hebrew_zadi)
	KEY_hebrew_qoph                 = uint(C.GDK_KEY_hebrew_qoph)
	KEY_hebrew_kuf                  = uint(C.GDK_KEY_hebrew_kuf)
	KEY_hebrew_resh                 = uint(C.GDK_KEY_hebrew_resh)
	KEY_hebrew_shin                 = uint(C.GDK_KEY_hebrew_shin)
	KEY_hebrew_taw                  = uint(C.GDK_KEY_hebrew_taw)
	KEY_hebrew_taf                  = uint(C.GDK_KEY_hebrew_taf)
	KEY_Hebrew_switch               = uint(C.GDK_KEY_Hebrew_switch)
	KEY_Thai_kokai                  = uint(C.GDK_KEY_Thai_kokai)
	KEY_Thai_khokhai                = uint(C.GDK_KEY_Thai_khokhai)
	KEY_Thai_khokhuat               = uint(C.GDK_KEY_Thai_khokhuat)
	KEY_Thai_khokhwai               = uint(C.GDK_KEY_Thai_khokhwai)
	KEY_Thai_khokhon                = uint(C.GDK_KEY_Thai_khokhon)
	KEY_Thai_khorakhang             = uint(C.GDK_KEY_Thai_khorakhang)
	KEY_Thai_ngongu                 = uint(C.GDK_KEY_Thai_ngongu)
	KEY_Thai_chochan                = uint(C.GDK_KEY_Thai_chochan)
	KEY_Thai_choching               = uint(C.GDK_KEY_Thai_choching)
	KEY_Thai_chochang               = uint(C.GDK_KEY_Thai_chochang)
	KEY_Thai_soso                   = uint(C.GDK_KEY_Thai_soso)
	KEY_Thai_chochoe                = uint(C.GDK_KEY_Thai_chochoe)
	KEY_Thai_yoying                 = uint(C.GDK_KEY_Thai_yoying)
	KEY_Thai_dochada                = uint(C.GDK_KEY_Thai_dochada)
	KEY_Thai_topatak                = uint(C.GDK_KEY_Thai_topatak)
	KEY_Thai_thothan                = uint(C.GDK_KEY_Thai_thothan)
	KEY_Thai_thonangmontho          = uint(C.GDK_KEY_Thai_thonangmontho)
	KEY_Thai_thophuthao             = uint(C.GDK_KEY_Thai_thophuthao)
	KEY_Thai_nonen                  = uint(C.GDK_KEY_Thai_nonen)
	KEY_Thai_dodek                  = uint(C.GDK_KEY_Thai_dodek)
	KEY_Thai_totao                  = uint(C.GDK_KEY_Thai_totao)
	KEY_Thai_thothung               = uint(C.GDK_KEY_Thai_thothung)
	KEY_Thai_thothahan              = uint(C.GDK_KEY_Thai_thothahan)
	KEY_Thai_thothong               = uint(C.GDK_KEY_Thai_thothong)
	KEY_Thai_nonu                   = uint(C.GDK_KEY_Thai_nonu)
	KEY_Thai_bobaimai               = uint(C.GDK_KEY_Thai_bobaimai)
	KEY_Thai_popla                  = uint(C.GDK_KEY_Thai_popla)
	KEY_Thai_phophung               = uint(C.GDK_KEY_Thai_phophung)
	KEY_Thai_fofa                   = uint(C.GDK_KEY_Thai_fofa)
	KEY_Thai_phophan                = uint(C.GDK_KEY_Thai_phophan)
	KEY_Thai_fofan                  = uint(C.GDK_KEY_Thai_fofan)
	KEY_Thai_phosamphao             = uint(C.GDK_KEY_Thai_phosamphao)
	KEY_Thai_moma                   = uint(C.GDK_KEY_Thai_moma)
	KEY_Thai_yoyak                  = uint(C.GDK_KEY_Thai_yoyak)
	KEY_Thai_rorua                  = uint(C.GDK_KEY_Thai_rorua)
	KEY_Thai_ru                     = uint(C.GDK_KEY_Thai_ru)
	KEY_Thai_loling                 = uint(C.GDK_KEY_Thai_loling)
	KEY_Thai_lu                     = uint(C.GDK_KEY_Thai_lu)
	KEY_Thai_wowaen                 = uint(C.GDK_KEY_Thai_wowaen)
	KEY_Thai_sosala                 = uint(C.GDK_KEY_Thai_sosala)
	KEY_Thai_sorusi                 = uint(C.GDK_KEY_Thai_sorusi)
	KEY_Thai_sosua                  = uint(C.GDK_KEY_Thai_sosua)
	KEY_Thai_hohip                  = uint(C.GDK_KEY_Thai_hohip)
	KEY_Thai_lochula                = uint(C.GDK_KEY_Thai_lochula)
	KEY_Thai_oang                   = uint(C.GDK_KEY_Thai_oang)
	KEY_Thai_honokhuk               = uint(C.GDK_KEY_Thai_honokhuk)
	KEY_Thai_paiyannoi              = uint(C.GDK_KEY_Thai_paiyannoi)
	KEY_Thai_saraa                  = uint(C.GDK_KEY_Thai_saraa)
	KEY_Thai_maihanakat             = uint(C.GDK_KEY_Thai_maihanakat)
	KEY_Thai_saraaa                 = uint(C.GDK_KEY_Thai_saraaa)
	KEY_Thai_saraam                 = uint(C.GDK_KEY_Thai_saraam)
	KEY_Thai_sarai                  = uint(C.GDK_KEY_Thai_sarai)
	KEY_Thai_saraii                 = uint(C.GDK_KEY_Thai_saraii)
	KEY_Thai_saraue                 = uint(C.GDK_KEY_Thai_saraue)
	KEY_Thai_sarauee                = uint(C.GDK_KEY_Thai_sarauee)
	KEY_Thai_sarau                  = uint(C.GDK_KEY_Thai_sarau)
	KEY_Thai_sarauu                 = uint(C.GDK_KEY_Thai_sarauu)
	KEY_Thai_phinthu                = uint(C.GDK_KEY_Thai_phinthu)
	KEY_Thai_maihanakat_maitho      = uint(C.GDK_KEY_Thai_maihanakat_maitho)
	KEY_Thai_baht                   = uint(C.GDK_KEY_Thai_baht)
	KEY_Thai_sarae                  = uint(C.GDK_KEY_Thai_sarae)
	KEY_Thai_saraae                 = uint(C.GDK_KEY_Thai_saraae)
	KEY_Thai_sarao                  = uint(C.GDK_KEY_Thai_sarao)
	KEY_Thai_saraaimaimuan          = uint(C.GDK_KEY_Thai_saraaimaimuan)
	KEY_Thai_saraaimaimalai         = uint(C.GDK_KEY_Thai_saraaimaimalai)
	KEY_Thai_lakkhangyao            = uint(C.GDK_KEY_Thai_lakkhangyao)
	KEY_Thai_maiyamok               = uint(C.GDK_KEY_Thai_maiyamok)
	KEY_Thai_maitaikhu              = uint(C.GDK_KEY_Thai_maitaikhu)
	KEY_Thai_maiek                  = uint(C.GDK_KEY_Thai_maiek)
	KEY_Thai_maitho                 = uint(C.GDK_KEY_Thai_maitho)
	KEY_Thai_maitri                 = uint(C.GDK_KEY_Thai_maitri)
	KEY_Thai_maichattawa            = uint(C.GDK_KEY_Thai_maichattawa)
	KEY_Thai_thanthakhat            = uint(C.GDK_KEY_Thai_thanthakhat)
	KEY_Thai_nikhahit               = uint(C.GDK_KEY_Thai_nikhahit)
	KEY_Thai_leksun                 = uint(C.GDK_KEY_Thai_leksun)
	KEY_Thai_leknung                = uint(C.GDK_KEY_Thai_leknung)
	KEY_Thai_leksong                = uint(C.GDK_KEY_Thai_leksong)
	KEY_Thai_leksam                 = uint(C.GDK_KEY_Thai_leksam)
	KEY_Thai_leksi                  = uint(C.GDK_KEY_Thai_leksi)
	KEY_Thai_lekha                  = uint(C.GDK_KEY_Thai_lekha)
	KEY_Thai_lekhok                 = uint(C.GDK_KEY_Thai_lekhok)
	KEY_Thai_lekchet                = uint(C.GDK_KEY_Thai_lekchet)
	KEY_Thai_lekpaet                = uint(C.GDK_KEY_Thai_lekpaet)
	KEY_Thai_lekkao                 = uint(C.GDK_KEY_Thai_lekkao)
	KEY_Hangul                      = uint(C.GDK_KEY_Hangul)
	KEY_Hangul_Start                = uint(C.GDK_KEY_Hangul_Start)
	KEY_Hangul_End                  = uint(C.GDK_KEY_Hangul_End)
	KEY_Hangul_Hanja                = uint(C.GDK_KEY_Hangul_Hanja)
	KEY_Hangul_Jamo                 = uint(C.GDK_KEY_Hangul_Jamo)
	KEY_Hangul_Romaja               = uint(C.GDK_KEY_Hangul_Romaja)
	KEY_Hangul_Codeinput            = uint(C.GDK_KEY_Hangul_Codeinput)
	KEY_Hangul_Jeonja               = uint(C.GDK_KEY_Hangul_Jeonja)
	KEY_Hangul_Banja                = uint(C.GDK_KEY_Hangul_Banja)
	KEY_Hangul_PreHanja             = uint(C.GDK_KEY_Hangul_PreHanja)
	KEY_Hangul_PostHanja            = uint(C.GDK_KEY_Hangul_PostHanja)
	KEY_Hangul_SingleCandidate      = uint(C.GDK_KEY_Hangul_SingleCandidate)
	KEY_Hangul_MultipleCandidate    = uint(C.GDK_KEY_Hangul_MultipleCandidate)
	KEY_Hangul_PreviousCandidate    = uint(C.GDK_KEY_Hangul_PreviousCandidate)
	KEY_Hangul_Special              = uint(C.GDK_KEY_Hangul_Special)
	KEY_Hangul_switch               = uint(C.GDK_KEY_Hangul_switch)
	KEY_Hangul_Kiyeog               = uint(C.GDK_KEY_Hangul_Kiyeog)
	KEY_Hangul_SsangKiyeog          = uint(C.GDK_KEY_Hangul_SsangKiyeog)
	KEY_Hangul_KiyeogSios           = uint(C.GDK_KEY_Hangul_KiyeogSios)
	KEY_Hangul_Nieun                = uint(C.GDK_KEY_Hangul_Nieun)
	KEY_Hangul_NieunJieuj           = uint(C.GDK_KEY_Hangul_NieunJieuj)
	KEY_Hangul_NieunHieuh           = uint(C.GDK_KEY_Hangul_NieunHieuh)
	KEY_Hangul_Dikeud               = uint(C.GDK_KEY_Hangul_Dikeud)
	KEY_Hangul_SsangDikeud          = uint(C.GDK_KEY_Hangul_SsangDikeud)
	KEY_Hangul_Rieul                = uint(C.GDK_KEY_Hangul_Rieul)
	KEY_Hangul_RieulKiyeog          = uint(C.GDK_KEY_Hangul_RieulKiyeog)
	KEY_Hangul_RieulMieum           = uint(C.GDK_KEY_Hangul_RieulMieum)
	KEY_Hangul_RieulPieub           = uint(C.GDK_KEY_Hangul_RieulPieub)
	KEY_Hangul_RieulSios            = uint(C.GDK_KEY_Hangul_RieulSios)
	KEY_Hangul_RieulTieut           = uint(C.GDK_KEY_Hangul_RieulTieut)
	KEY_Hangul_RieulPhieuf          = uint(C.GDK_KEY_Hangul_RieulPhieuf)
	KEY_Hangul_RieulHieuh           = uint(C.GDK_KEY_Hangul_RieulHieuh)
	KEY_Hangul_Mieum                = uint(C.GDK_KEY_Hangul_Mieum)
	KEY_Hangul_Pieub                = uint(C.GDK_KEY_Hangul_Pieub)
	KEY_Hangul_SsangPieub           = uint(C.GDK_KEY_Hangul_SsangPieub)
	KEY_Hangul_PieubSios            = uint(C.GDK_KEY_Hangul_PieubSios)
	KEY_Hangul_Sios                 = uint(C.GDK_KEY_Hangul_Sios)
	KEY_Hangul_SsangSios            = uint(C.GDK_KEY_Hangul_SsangSios)
	KEY_Hangul_Ieung                = uint(C.GDK_KEY_Hangul_Ieung)
	KEY_Hangul_Jieuj                = uint(C.GDK_KEY_Hangul_Jieuj)
	KEY_Hangul_SsangJieuj           = uint(C.GDK_KEY_Hangul_SsangJieuj)
	KEY_Hangul_Cieuc                = uint(C.GDK_KEY_Hangul_Cieuc)
	KEY_Hangul_Khieuq               = uint(C.GDK_KEY_Hangul_Khieuq)
	KEY_Hangul_Tieut                = uint(C.GDK_KEY_Hangul_Tieut)
	KEY_Hangul_Phieuf               = uint(C.GDK_KEY_Hangul_Phieuf)
	KEY_Hangul_Hieuh                = uint(C.GDK_KEY_Hangul_Hieuh)
	KEY_Hangul_A                    = uint(C.GDK_KEY_Hangul_A)
	KEY_Hangul_AE                   = uint(C.GDK_KEY_Hangul_AE)
	KEY_Hangul_YA                   = uint(C.GDK_KEY_Hangul_YA)
	KEY_Hangul_YAE                  = uint(C.GDK_KEY_Hangul_YAE)
	KEY_Hangul_EO                   = uint(C.GDK_KEY_Hangul_EO)
	KEY_Hangul_E                    = uint(C.GDK_KEY_Hangul_E)
	KEY_Hangul_YEO                  = uint(C.GDK_KEY_Hangul_YEO)
	KEY_Hangul_YE                   = uint(C.GDK_KEY_Hangul_YE)
	KEY_Hangul_O                    = uint(C.GDK_KEY_Hangul_O)
	KEY_Hangul_WA                   = uint(C.GDK_KEY_Hangul_WA)
	KEY_Hangul_WAE                  = uint(C.GDK_KEY_Hangul_WAE)
	KEY_Hangul_OE                   = uint(C.GDK_KEY_Hangul_OE)
	KEY_Hangul_YO                   = uint(C.GDK_KEY_Hangul_YO)
	KEY_Hangul_U                    = uint(C.GDK_KEY_Hangul_U)
	KEY_Hangul_WEO                  = uint(C.GDK_KEY_Hangul_WEO)
	KEY_Hangul_WE                   = uint(C.GDK_KEY_Hangul_WE)
	KEY_Hangul_WI                   = uint(C.GDK_KEY_Hangul_WI)
	KEY_Hangul_YU                   = uint(C.GDK_KEY_Hangul_YU)
	KEY_Hangul_EU                   = uint(C.GDK_KEY_Hangul_EU)
	KEY_Hangul_YI                   = uint(C.GDK_KEY_Hangul_YI)
	KEY_Hangul_I                    = uint(C.GDK_KEY_Hangul_I)
	KEY_Hangul_J_Kiyeog             = uint(C.GDK_KEY_Hangul_J_Kiyeog)
	KEY_Hangul_J_SsangKiyeog        = uint(C.GDK_KEY_Hangul_J_SsangKiyeog)
	KEY_Hangul_J_KiyeogSios         = uint(C.GDK_KEY_Hangul_J_KiyeogSios)
	KEY_Hangul_J_Nieun              = uint(C.GDK_KEY_Hangul_J_Nieun)
	KEY_Hangul_J_NieunJieuj         = uint(C.GDK_KEY_Hangul_J_NieunJieuj)
	KEY_Hangul_J_NieunHieuh         = uint(C.GDK_KEY_Hangul_J_NieunHieuh)
	KEY_Hangul_J_Dikeud             = uint(C.GDK_KEY_Hangul_J_Dikeud)
	KEY_Hangul_J_Rieul              = uint(C.GDK_KEY_Hangul_J_Rieul)
	KEY_Hangul_J_RieulKiyeog        = uint(C.GDK_KEY_Hangul_J_RieulKiyeog)
	KEY_Hangul_J_RieulMieum         = uint(C.GDK_KEY_Hangul_J_RieulMieum)
	KEY_Hangul_J_RieulPieub         = uint(C.GDK_KEY_Hangul_J_RieulPieub)
	KEY_Hangul_J_RieulSios          = uint(C.GDK_KEY_Hangul_J_RieulSios)
	KEY_Hangul_J_RieulTieut         = uint(C.GDK_KEY_Hangul_J_RieulTieut)
	KEY_Hangul_J_RieulPhieuf        = uint(C.GDK_KEY_Hangul_J_RieulPhieuf)
	KEY_Hangul_J_RieulHieuh         = uint(C.GDK_KEY_Hangul_J_RieulHieuh)
	KEY_Hangul_J_Mieum              = uint(C.GDK_KEY_Hangul_J_Mieum)
	KEY_Hangul_J_Pieub              = uint(C.GDK_KEY_Hangul_J_Pieub)
	KEY_Hangul_J_PieubSios          = uint(C.GDK_KEY_Hangul_J_PieubSios)
	KEY_Hangul_J_Sios               = uint(C.GDK_KEY_Hangul_J_Sios)
	KEY_Hangul_J_SsangSios          = uint(C.GDK_KEY_Hangul_J_SsangSios)
	KEY_Hangul_J_Ieung              = uint(C.GDK_KEY_Hangul_J_Ieung)
	KEY_Hangul_J_Jieuj              = uint(C.GDK_KEY_Hangul_J_Jieuj)
	KEY_Hangul_J_Cieuc              = uint(C.GDK_KEY_Hangul_J_Cieuc)
	KEY_Hangul_J_Khieuq             = uint(C.GDK_KEY_Hangul_J_Khieuq)
	KEY_Hangul_J_Tieut              = uint(C.GDK_KEY_Hangul_J_Tieut)
	KEY_Hangul_J_Phieuf             = uint(C.GDK_KEY_Hangul_J_Phieuf)
	KEY_Hangul_J_Hieuh              = uint(C.GDK_KEY_Hangul_J_Hieuh)
	KEY_Hangul_RieulYeorinHieuh     = uint(C.GDK_KEY_Hangul_RieulYeorinHieuh)
	KEY_Hangul_SunkyeongeumMieum    = uint(C.GDK_KEY_Hangul_SunkyeongeumMieum)
	KEY_Hangul_SunkyeongeumPieub    = uint(C.GDK_KEY_Hangul_SunkyeongeumPieub)
	KEY_Hangul_PanSios              = uint(C.GDK_KEY_Hangul_PanSios)
	KEY_Hangul_KkogjiDalrinIeung    = uint(C.GDK_KEY_Hangul_KkogjiDalrinIeung)
	KEY_Hangul_SunkyeongeumPhieuf   = uint(C.GDK_KEY_Hangul_SunkyeongeumPhieuf)
	KEY_Hangul_YeorinHieuh          = uint(C.GDK_KEY_Hangul_YeorinHieuh)
	KEY_Hangul_AraeA                = uint(C.GDK_KEY_Hangul_AraeA)
	KEY_Hangul_AraeAE               = uint(C.GDK_KEY_Hangul_AraeAE)
	KEY_Hangul_J_PanSios            = uint(C.GDK_KEY_Hangul_J_PanSios)
	KEY_Hangul_J_KkogjiDalrinIeung  = uint(C.GDK_KEY_Hangul_J_KkogjiDalrinIeung)
	KEY_Hangul_J_YeorinHieuh        = uint(C.GDK_KEY_Hangul_J_YeorinHieuh)
	KEY_Korean_Won                  = uint(C.GDK_KEY_Korean_Won)
	KEY_Armenian_ligature_ew        = uint(C.GDK_KEY_Armenian_ligature_ew)
	KEY_Armenian_full_stop          = uint(C.GDK_KEY_Armenian_full_stop)
	KEY_Armenian_verjaket           = uint(C.GDK_KEY_Armenian_verjaket)
	KEY_Armenian_separation_mark    = uint(C.GDK_KEY_Armenian_separation_mark)
	KEY_Armenian_but                = uint(C.GDK_KEY_Armenian_but)
	KEY_Armenian_hyphen             = uint(C.GDK_KEY_Armenian_hyphen)
	KEY_Armenian_yentamna           = uint(C.GDK_KEY_Armenian_yentamna)
	KEY_Armenian_exclam             = uint(C.GDK_KEY_Armenian_exclam)
	KEY_Armenian_amanak             = uint(C.GDK_KEY_Armenian_amanak)
	KEY_Armenian_accent             = uint(C.GDK_KEY_Armenian_accent)
	KEY_Armenian_shesht             = uint(C.GDK_KEY_Armenian_shesht)
	KEY_Armenian_question           = uint(C.GDK_KEY_Armenian_question)
	KEY_Armenian_paruyk             = uint(C.GDK_KEY_Armenian_paruyk)
	KEY_Armenian_AYB                = uint(C.GDK_KEY_Armenian_AYB)
	KEY_Armenian_ayb                = uint(C.GDK_KEY_Armenian_ayb)
	KEY_Armenian_BEN                = uint(C.GDK_KEY_Armenian_BEN)
	KEY_Armenian_ben                = uint(C.GDK_KEY_Armenian_ben)
	KEY_Armenian_GIM                = uint(C.GDK_KEY_Armenian_GIM)
	KEY_Armenian_gim                = uint(C.GDK_KEY_Armenian_gim)
	KEY_Armenian_DA                 = uint(C.GDK_KEY_Armenian_DA)
	KEY_Armenian_da                 = uint(C.GDK_KEY_Armenian_da)
	KEY_Armenian_YECH               = uint(C.GDK_KEY_Armenian_YECH)
	KEY_Armenian_yech               = uint(C.GDK_KEY_Armenian_yech)
	KEY_Armenian_ZA                 = uint(C.GDK_KEY_Armenian_ZA)
	KEY_Armenian_za                 = uint(C.GDK_KEY_Armenian_za)
	KEY_Armenian_E                  = uint(C.GDK_KEY_Armenian_E)
	KEY_Armenian_e                  = uint(C.GDK_KEY_Armenian_e)
	KEY_Armenian_AT                 = uint(C.GDK_KEY_Armenian_AT)
	KEY_Armenian_at                 = uint(C.GDK_KEY_Armenian_at)
	KEY_Armenian_TO                 = uint(C.GDK_KEY_Armenian_TO)
	KEY_Armenian_to                 = uint(C.GDK_KEY_Armenian_to)
	KEY_Armenian_ZHE                = uint(C.GDK_KEY_Armenian_ZHE)
	KEY_Armenian_zhe                = uint(C.GDK_KEY_Armenian_zhe)
	KEY_Armenian_INI                = uint(C.GDK_KEY_Armenian_INI)
	KEY_Armenian_ini                = uint(C.GDK_KEY_Armenian_ini)
	KEY_Armenian_LYUN               = uint(C.GDK_KEY_Armenian_LYUN)
	KEY_Armenian_lyun               = uint(C.GDK_KEY_Armenian_lyun)
	KEY_Armenian_KHE                = uint(C.GDK_KEY_Armenian_KHE)
	KEY_Armenian_khe                = uint(C.GDK_KEY_Armenian_khe)
	KEY_Armenian_TSA                = uint(C.GDK_KEY_Armenian_TSA)
	KEY_Armenian_tsa                = uint(C.GDK_KEY_Armenian_tsa)
	KEY_Armenian_KEN                = uint(C.GDK_KEY_Armenian_KEN)
	KEY_Armenian_ken                = uint(C.GDK_KEY_Armenian_ken)
	KEY_Armenian_HO                 = uint(C.GDK_KEY_Armenian_HO)
	KEY_Armenian_ho                 = uint(C.GDK_KEY_Armenian_ho)
	KEY_Armenian_DZA                = uint(C.GDK_KEY_Armenian_DZA)
	KEY_Armenian_dza                = uint(C.GDK_KEY_Armenian_dza)
	KEY_Armenian_GHAT               = uint(C.GDK_KEY_Armenian_GHAT)
	KEY_Armenian_ghat               = uint(C.GDK_KEY_Armenian_ghat)
	KEY_Armenian_TCHE               = uint(C.GDK_KEY_Armenian_TCHE)
	KEY_Armenian_tche               = uint(C.GDK_KEY_Armenian_tche)
	KEY_Armenian_MEN                = uint(C.GDK_KEY_Armenian_MEN)
	KEY_Armenian_men                = uint(C.GDK_KEY_Armenian_men)
	KEY_Armenian_HI                 = uint(C.GDK_KEY_Armenian_HI)
	KEY_Armenian_hi                 = uint(C.GDK_KEY_Armenian_hi)
	KEY_Armenian_NU                 = uint(C.GDK_KEY_Armenian_NU)
	KEY_Armenian_nu                 = uint(C.GDK_KEY_Armenian_nu)
	KEY_Armenian_SHA                = uint(C.GDK_KEY_Armenian_SHA)
	KEY_Armenian_sha                = uint(C.GDK_KEY_Armenian_sha)
	KEY_Armenian_VO                 = uint(C.GDK_KEY_Armenian_VO)
	KEY_Armenian_vo                 = uint(C.GDK_KEY_Armenian_vo)
	KEY_Armenian_CHA                = uint(C.GDK_KEY_Armenian_CHA)
	KEY_Armenian_cha                = uint(C.GDK_KEY_Armenian_cha)
	KEY_Armenian_PE                 = uint(C.GDK_KEY_Armenian_PE)
	KEY_Armenian_pe                 = uint(C.GDK_KEY_Armenian_pe)
	KEY_Armenian_JE                 = uint(C.GDK_KEY_Armenian_JE)
	KEY_Armenian_je                 = uint(C.GDK_KEY_Armenian_je)
	KEY_Armenian_RA                 = uint(C.GDK_KEY_Armenian_RA)
	KEY_Armenian_ra                 = uint(C.GDK_KEY_Armenian_ra)
	KEY_Armenian_SE                 = uint(C.GDK_KEY_Armenian_SE)
	KEY_Armenian_se                 = uint(C.GDK_KEY_Armenian_se)
	KEY_Armenian_VEV                = uint(C.GDK_KEY_Armenian_VEV)
	KEY_Armenian_vev                = uint(C.GDK_KEY_Armenian_vev)
	KEY_Armenian_TYUN               = uint(C.GDK_KEY_Armenian_TYUN)
	KEY_Armenian_tyun               = uint(C.GDK_KEY_Armenian_tyun)
	KEY_Armenian_RE                 = uint(C.GDK_KEY_Armenian_RE)
	KEY_Armenian_re                 = uint(C.GDK_KEY_Armenian_re)
	KEY_Armenian_TSO                = uint(C.GDK_KEY_Armenian_TSO)
	KEY_Armenian_tso                = uint(C.GDK_KEY_Armenian_tso)
	KEY_Armenian_VYUN               = uint(C.GDK_KEY_Armenian_VYUN)
	KEY_Armenian_vyun               = uint(C.GDK_KEY_Armenian_vyun)
	KEY_Armenian_PYUR               = uint(C.GDK_KEY_Armenian_PYUR)
	KEY_Armenian_pyur               = uint(C.GDK_KEY_Armenian_pyur)
	KEY_Armenian_KE                 = uint(C.GDK_KEY_Armenian_KE)
	KEY_Armenian_ke                 = uint(C.GDK_KEY_Armenian_ke)
	KEY_Armenian_O                  = uint(C.GDK_KEY_Armenian_O)
	KEY_Armenian_o                  = uint(C.GDK_KEY_Armenian_o)
	KEY_Armenian_FE                 = uint(C.GDK_KEY_Armenian_FE)
	KEY_Armenian_fe                 = uint(C.GDK_KEY_Armenian_fe)
	KEY_Armenian_apostrophe         = uint(C.GDK_KEY_Armenian_apostrophe)
	KEY_Georgian_an                 = uint(C.GDK_KEY_Georgian_an)
	KEY_Georgian_ban                = uint(C.GDK_KEY_Georgian_ban)
	KEY_Georgian_gan                = uint(C.GDK_KEY_Georgian_gan)
	KEY_Georgian_don                = uint(C.GDK_KEY_Georgian_don)
	KEY_Georgian_en                 = uint(C.GDK_KEY_Georgian_en)
	KEY_Georgian_vin                = uint(C.GDK_KEY_Georgian_vin)
	KEY_Georgian_zen                = uint(C.GDK_KEY_Georgian_zen)
	KEY_Georgian_tan                = uint(C.GDK_KEY_Georgian_tan)
	KEY_Georgian_in                 = uint(C.GDK_KEY_Georgian_in)
	KEY_Georgian_kan                = uint(C.GDK_KEY_Georgian_kan)
	KEY_Georgian_las                = uint(C.GDK_KEY_Georgian_las)
	KEY_Georgian_man                = uint(C.GDK_KEY_Georgian_man)
	KEY_Georgian_nar                = uint(C.GDK_KEY_Georgian_nar)
	KEY_Georgian_on                 = uint(C.GDK_KEY_Georgian_on)
	KEY_Georgian_par                = uint(C.GDK_KEY_Georgian_par)
	KEY_Georgian_zhar               = uint(C.GDK_KEY_Georgian_zhar)
	KEY_Georgian_rae                = uint(C.GDK_KEY_Georgian_rae)
	KEY_Georgian_san                = uint(C.GDK_KEY_Georgian_san)
	KEY_Georgian_tar                = uint(C.GDK_KEY_Georgian_tar)
	KEY_Georgian_un                 = uint(C.GDK_KEY_Georgian_un)
	KEY_Georgian_phar               = uint(C.GDK_KEY_Georgian_phar)
	KEY_Georgian_khar               = uint(C.GDK_KEY_Georgian_khar)
	KEY_Georgian_ghan               = uint(C.GDK_KEY_Georgian_ghan)
	KEY_Georgian_qar                = uint(C.GDK_KEY_Georgian_qar)
	KEY_Georgian_shin               = uint(C.GDK_KEY_Georgian_shin)
	KEY_Georgian_chin               = uint(C.GDK_KEY_Georgian_chin)
	KEY_Georgian_can                = uint(C.GDK_KEY_Georgian_can)
	KEY_Georgian_jil                = uint(C.GDK_KEY_Georgian_jil)
	KEY_Georgian_cil                = uint(C.GDK_KEY_Georgian_cil)
	KEY_Georgian_char               = uint(C.GDK_KEY_Georgian_char)
	KEY_Georgian_xan                = uint(C.GDK_KEY_Georgian_xan)
	KEY_Georgian_jhan               = uint(C.GDK_KEY_Georgian_jhan)
	KEY_Georgian_hae                = uint(C.GDK_KEY_Georgian_hae)
	KEY_Georgian_he                 = uint(C.GDK_KEY_Georgian_he)
	KEY_Georgian_hie                = uint(C.GDK_KEY_Georgian_hie)
	KEY_Georgian_we                 = uint(C.GDK_KEY_Georgian_we)
	KEY_Georgian_har                = uint(C.GDK_KEY_Georgian_har)
	KEY_Georgian_hoe                = uint(C.GDK_KEY_Georgian_hoe)
	KEY_Georgian_fi                 = uint(C.GDK_KEY_Georgian_fi)
	KEY_Xabovedot                   = uint(C.GDK_KEY_Xabovedot)
	KEY_Ibreve                      = uint(C.GDK_KEY_Ibreve)
	KEY_Zstroke                     = uint(C.GDK_KEY_Zstroke)
	KEY_Gcaron                      = uint(C.GDK_KEY_Gcaron)
	KEY_Ocaron                      = uint(C.GDK_KEY_Ocaron)
	KEY_Obarred                     = uint(C.GDK_KEY_Obarred)
	KEY_xabovedot                   = uint(C.GDK_KEY_xabovedot)
	KEY_ibreve                      = uint(C.GDK_KEY_ibreve)
	KEY_zstroke                     = uint(C.GDK_KEY_zstroke)
	KEY_gcaron                      = uint(C.GDK_KEY_gcaron)
	KEY_ocaron                      = uint(C.GDK_KEY_ocaron)
	KEY_obarred                     = uint(C.GDK_KEY_obarred)
	KEY_SCHWA                       = uint(C.GDK_KEY_SCHWA)
	KEY_schwa                       = uint(C.GDK_KEY_schwa)
	KEY_EZH                         = uint(C.GDK_KEY_EZH)
	KEY_ezh                         = uint(C.GDK_KEY_ezh)
	KEY_Lbelowdot                   = uint(C.GDK_KEY_Lbelowdot)
	KEY_lbelowdot                   = uint(C.GDK_KEY_lbelowdot)
	KEY_Abelowdot                   = uint(C.GDK_KEY_Abelowdot)
	KEY_abelowdot                   = uint(C.GDK_KEY_abelowdot)
	KEY_Ahook                       = uint(C.GDK_KEY_Ahook)
	KEY_ahook                       = uint(C.GDK_KEY_ahook)
	KEY_Acircumflexacute            = uint(C.GDK_KEY_Acircumflexacute)
	KEY_acircumflexacute            = uint(C.GDK_KEY_acircumflexacute)
	KEY_Acircumflexgrave            = uint(C.GDK_KEY_Acircumflexgrave)
	KEY_acircumflexgrave            = uint(C.GDK_KEY_acircumflexgrave)
	KEY_Acircumflexhook             = uint(C.GDK_KEY_Acircumflexhook)
	KEY_acircumflexhook             = uint(C.GDK_KEY_acircumflexhook)
	KEY_Acircumflextilde            = uint(C.GDK_KEY_Acircumflextilde)
	KEY_acircumflextilde            = uint(C.GDK_KEY_acircumflextilde)
	KEY_Acircumflexbelowdot         = uint(C.GDK_KEY_Acircumflexbelowdot)
	KEY_acircumflexbelowdot         = uint(C.GDK_KEY_acircumflexbelowdot)
	KEY_Abreveacute                 = uint(C.GDK_KEY_Abreveacute)
	KEY_abreveacute                 = uint(C.GDK_KEY_abreveacute)
	KEY_Abrevegrave                 = uint(C.GDK_KEY_Abrevegrave)
	KEY_abrevegrave                 = uint(C.GDK_KEY_abrevegrave)
	KEY_Abrevehook                  = uint(C.GDK_KEY_Abrevehook)
	KEY_abrevehook                  = uint(C.GDK_KEY_abrevehook)
	KEY_Abrevetilde                 = uint(C.GDK_KEY_Abrevetilde)
	KEY_abrevetilde                 = uint(C.GDK_KEY_abrevetilde)
	KEY_Abrevebelowdot              = uint(C.GDK_KEY_Abrevebelowdot)
	KEY_abrevebelowdot              = uint(C.GDK_KEY_abrevebelowdot)
	KEY_Ebelowdot                   = uint(C.GDK_KEY_Ebelowdot)
	KEY_ebelowdot                   = uint(C.GDK_KEY_ebelowdot)
	KEY_Ehook                       = uint(C.GDK_KEY_Ehook)
	KEY_ehook                       = uint(C.GDK_KEY_ehook)
	KEY_Etilde                      = uint(C.GDK_KEY_Etilde)
	KEY_etilde                      = uint(C.GDK_KEY_etilde)
	KEY_Ecircumflexacute            = uint(C.GDK_KEY_Ecircumflexacute)
	KEY_ecircumflexacute            = uint(C.GDK_KEY_ecircumflexacute)
	KEY_Ecircumflexgrave            = uint(C.GDK_KEY_Ecircumflexgrave)
	KEY_ecircumflexgrave            = uint(C.GDK_KEY_ecircumflexgrave)
	KEY_Ecircumflexhook             = uint(C.GDK_KEY_Ecircumflexhook)
	KEY_ecircumflexhook             = uint(C.GDK_KEY_ecircumflexhook)
	KEY_Ecircumflextilde            = uint(C.GDK_KEY_Ecircumflextilde)
	KEY_ecircumflextilde            = uint(C.GDK_KEY_ecircumflextilde)
	KEY_Ecircumflexbelowdot         = uint(C.GDK_KEY_Ecircumflexbelowdot)
	KEY_ecircumflexbelowdot         = uint(C.GDK_KEY_ecircumflexbelowdot)
	KEY_Ihook                       = uint(C.GDK_KEY_Ihook)
	KEY_ihook                       = uint(C.GDK_KEY_ihook)
	KEY_Ibelowdot                   = uint(C.GDK_KEY_Ibelowdot)
	KEY_ibelowdot                   = uint(C.GDK_KEY_ibelowdot)
	KEY_Obelowdot                   = uint(C.GDK_KEY_Obelowdot)
	KEY_obelowdot                   = uint(C.GDK_KEY_obelowdot)
	KEY_Ohook                       = uint(C.GDK_KEY_Ohook)
	KEY_ohook                       = uint(C.GDK_KEY_ohook)
	KEY_Ocircumflexacute            = uint(C.GDK_KEY_Ocircumflexacute)
	KEY_ocircumflexacute            = uint(C.GDK_KEY_ocircumflexacute)
	KEY_Ocircumflexgrave            = uint(C.GDK_KEY_Ocircumflexgrave)
	KEY_ocircumflexgrave            = uint(C.GDK_KEY_ocircumflexgrave)
	KEY_Ocircumflexhook             = uint(C.GDK_KEY_Ocircumflexhook)
	KEY_ocircumflexhook             = uint(C.GDK_KEY_ocircumflexhook)
	KEY_Ocircumflextilde            = uint(C.GDK_KEY_Ocircumflextilde)
	KEY_ocircumflextilde            = uint(C.GDK_KEY_ocircumflextilde)
	KEY_Ocircumflexbelowdot         = uint(C.GDK_KEY_Ocircumflexbelowdot)
	KEY_ocircumflexbelowdot         = uint(C.GDK_KEY_ocircumflexbelowdot)
	KEY_Ohornacute                  = uint(C.GDK_KEY_Ohornacute)
	KEY_ohornacute                  = uint(C.GDK_KEY_ohornacute)
	KEY_Ohorngrave                  = uint(C.GDK_KEY_Ohorngrave)
	KEY_ohorngrave                  = uint(C.GDK_KEY_ohorngrave)
	KEY_Ohornhook                   = uint(C.GDK_KEY_Ohornhook)
	KEY_ohornhook                   = uint(C.GDK_KEY_ohornhook)
	KEY_Ohorntilde                  = uint(C.GDK_KEY_Ohorntilde)
	KEY_ohorntilde                  = uint(C.GDK_KEY_ohorntilde)
	KEY_Ohornbelowdot               = uint(C.GDK_KEY_Ohornbelowdot)
	KEY_ohornbelowdot               = uint(C.GDK_KEY_ohornbelowdot)
	KEY_Ubelowdot                   = uint(C.GDK_KEY_Ubelowdot)
	KEY_ubelowdot                   = uint(C.GDK_KEY_ubelowdot)
	KEY_Uhook                       = uint(C.GDK_KEY_Uhook)
	KEY_uhook                       = uint(C.GDK_KEY_uhook)
	KEY_Uhornacute                  = uint(C.GDK_KEY_Uhornacute)
	KEY_uhornacute                  = uint(C.GDK_KEY_uhornacute)
	KEY_Uhorngrave                  = uint(C.GDK_KEY_Uhorngrave)
	KEY_uhorngrave                  = uint(C.GDK_KEY_uhorngrave)
	KEY_Uhornhook                   = uint(C.GDK_KEY_Uhornhook)
	KEY_uhornhook                   = uint(C.GDK_KEY_uhornhook)
	KEY_Uhorntilde                  = uint(C.GDK_KEY_Uhorntilde)
	KEY_uhorntilde                  = uint(C.GDK_KEY_uhorntilde)
	KEY_Uhornbelowdot               = uint(C.GDK_KEY_Uhornbelowdot)
	KEY_uhornbelowdot               = uint(C.GDK_KEY_uhornbelowdot)
	KEY_Ybelowdot                   = uint(C.GDK_KEY_Ybelowdot)
	KEY_ybelowdot                   = uint(C.GDK_KEY_ybelowdot)
	KEY_Yhook                       = uint(C.GDK_KEY_Yhook)
	KEY_yhook                       = uint(C.GDK_KEY_yhook)
	KEY_Ytilde                      = uint(C.GDK_KEY_Ytilde)
	KEY_ytilde                      = uint(C.GDK_KEY_ytilde)
	KEY_Ohorn                       = uint(C.GDK_KEY_Ohorn)
	KEY_ohorn                       = uint(C.GDK_KEY_ohorn)
	KEY_Uhorn                       = uint(C.GDK_KEY_Uhorn)
	KEY_uhorn                       = uint(C.GDK_KEY_uhorn)
	KEY_EcuSign                     = uint(C.GDK_KEY_EcuSign)
	KEY_ColonSign                   = uint(C.GDK_KEY_ColonSign)
	KEY_CruzeiroSign                = uint(C.GDK_KEY_CruzeiroSign)
	KEY_FFrancSign                  = uint(C.GDK_KEY_FFrancSign)
	KEY_LiraSign                    = uint(C.GDK_KEY_LiraSign)
	KEY_MillSign                    = uint(C.GDK_KEY_MillSign)
	KEY_NairaSign                   = uint(C.GDK_KEY_NairaSign)
	KEY_PesetaSign                  = uint(C.GDK_KEY_PesetaSign)
	KEY_RupeeSign                   = uint(C.GDK_KEY_RupeeSign)
	KEY_WonSign                     = uint(C.GDK_KEY_WonSign)
	KEY_NewSheqelSign               = uint(C.GDK_KEY_NewSheqelSign)
	KEY_DongSign                    = uint(C.GDK_KEY_DongSign)
	KEY_EuroSign                    = uint(C.GDK_KEY_EuroSign)
	KEY_zerosuperior                = uint(C.GDK_KEY_zerosuperior)
	KEY_foursuperior                = uint(C.GDK_KEY_foursuperior)
	KEY_fivesuperior                = uint(C.GDK_KEY_fivesuperior)
	KEY_sixsuperior                 = uint(C.GDK_KEY_sixsuperior)
	KEY_sevensuperior               = uint(C.GDK_KEY_sevensuperior)
	KEY_eightsuperior               = uint(C.GDK_KEY_eightsuperior)
	KEY_ninesuperior                = uint(C.GDK_KEY_ninesuperior)
	KEY_zerosubscript               = uint(C.GDK_KEY_zerosubscript)
	KEY_onesubscript                = uint(C.GDK_KEY_onesubscript)
	KEY_twosubscript                = uint(C.GDK_KEY_twosubscript)
	KEY_threesubscript              = uint(C.GDK_KEY_threesubscript)
	KEY_foursubscript               = uint(C.GDK_KEY_foursubscript)
	KEY_fivesubscript               = uint(C.GDK_KEY_fivesubscript)
	KEY_sixsubscript                = uint(C.GDK_KEY_sixsubscript)
	KEY_sevensubscript              = uint(C.GDK_KEY_sevensubscript)
	KEY_eightsubscript              = uint(C.GDK_KEY_eightsubscript)
	KEY_ninesubscript               = uint(C.GDK_KEY_ninesubscript)
	KEY_partdifferential            = uint(C.GDK_KEY_partdifferential)
	KEY_emptyset                    = uint(C.GDK_KEY_emptyset)
	KEY_elementof                   = uint(C.GDK_KEY_elementof)
	KEY_notelementof                = uint(C.GDK_KEY_notelementof)
	KEY_containsas                  = uint(C.GDK_KEY_containsas)
	KEY_squareroot                  = uint(C.GDK_KEY_squareroot)
	KEY_cuberoot                    = uint(C.GDK_KEY_cuberoot)
	KEY_fourthroot                  = uint(C.GDK_KEY_fourthroot)
	KEY_dintegral                   = uint(C.GDK_KEY_dintegral)
	KEY_tintegral                   = uint(C.GDK_KEY_tintegral)
	KEY_because                     = uint(C.GDK_KEY_because)
	KEY_approxeq                    = uint(C.GDK_KEY_approxeq)
	KEY_notapproxeq                 = uint(C.GDK_KEY_notapproxeq)
	KEY_notidentical                = uint(C.GDK_KEY_notidentical)
	KEY_stricteq                    = uint(C.GDK_KEY_stricteq)
	KEY_braille_dot_1               = uint(C.GDK_KEY_braille_dot_1)
	KEY_braille_dot_2               = uint(C.GDK_KEY_braille_dot_2)
	KEY_braille_dot_3               = uint(C.GDK_KEY_braille_dot_3)
	KEY_braille_dot_4               = uint(C.GDK_KEY_braille_dot_4)
	KEY_braille_dot_5               = uint(C.GDK_KEY_braille_dot_5)
	KEY_braille_dot_6               = uint(C.GDK_KEY_braille_dot_6)
	KEY_braille_dot_7               = uint(C.GDK_KEY_braille_dot_7)
	KEY_braille_dot_8               = uint(C.GDK_KEY_braille_dot_8)
	KEY_braille_dot_9               = uint(C.GDK_KEY_braille_dot_9)
	KEY_braille_dot_10              = uint(C.GDK_KEY_braille_dot_10)
	KEY_braille_blank               = uint(C.GDK_KEY_braille_blank)
	KEY_braille_dots_1              = uint(C.GDK_KEY_braille_dots_1)
	KEY_braille_dots_2              = uint(C.GDK_KEY_braille_dots_2)
	KEY_braille_dots_12             = uint(C.GDK_KEY_braille_dots_12)
	KEY_braille_dots_3              = uint(C.GDK_KEY_braille_dots_3)
	KEY_braille_dots_13             = uint(C.GDK_KEY_braille_dots_13)
	KEY_braille_dots_23             = uint(C.GDK_KEY_braille_dots_23)
	KEY_braille_dots_123            = uint(C.GDK_KEY_braille_dots_123)
	KEY_braille_dots_4              = uint(C.GDK_KEY_braille_dots_4)
	KEY_braille_dots_14             = uint(C.GDK_KEY_braille_dots_14)
	KEY_braille_dots_24             = uint(C.GDK_KEY_braille_dots_24)
	KEY_braille_dots_124            = uint(C.GDK_KEY_braille_dots_124)
	KEY_braille_dots_34             = uint(C.GDK_KEY_braille_dots_34)
	KEY_braille_dots_134            = uint(C.GDK_KEY_braille_dots_134)
	KEY_braille_dots_234            = uint(C.GDK_KEY_braille_dots_234)
	KEY_braille_dots_1234           = uint(C.GDK_KEY_braille_dots_1234)
	KEY_braille_dots_5              = uint(C.GDK_KEY_braille_dots_5)
	KEY_braille_dots_15             = uint(C.GDK_KEY_braille_dots_15)
	KEY_braille_dots_25             = uint(C.GDK_KEY_braille_dots_25)
	KEY_braille_dots_125            = uint(C.GDK_KEY_braille_dots_125)
	KEY_braille_dots_35             = uint(C.GDK_KEY_braille_dots_35)
	KEY_braille_dots_135            = uint(C.GDK_KEY_braille_dots_135)
	KEY_braille_dots_235            = uint(C.GDK_KEY_braille_dots_235)
	KEY_braille_dots_1235           = uint(C.GDK_KEY_braille_dots_1235)
	KEY_braille_dots_45             = uint(C.GDK_KEY_braille_dots_45)
	KEY_braille_dots_145            = uint(C.GDK_KEY_braille_dots_145)
	KEY_braille_dots_245            = uint(C.GDK_KEY_braille_dots_245)
	KEY_braille_dots_1245           = uint(C.GDK_KEY_braille_dots_1245)
	KEY_braille_dots_345            = uint(C.GDK_KEY_braille_dots_345)
	KEY_braille_dots_1345           = uint(C.GDK_KEY_braille_dots_1345)
	KEY_braille_dots_2345           = uint(C.GDK_KEY_braille_dots_2345)
	KEY_braille_dots_12345          = uint(C.GDK_KEY_braille_dots_12345)
	KEY_braille_dots_6              = uint(C.GDK_KEY_braille_dots_6)
	KEY_braille_dots_16             = uint(C.GDK_KEY_braille_dots_16)
	KEY_braille_dots_26             = uint(C.GDK_KEY_braille_dots_26)
	KEY_braille_dots_126            = uint(C.GDK_KEY_braille_dots_126)
	KEY_braille_dots_36             = uint(C.GDK_KEY_braille_dots_36)
	KEY_braille_dots_136            = uint(C.GDK_KEY_braille_dots_136)
	KEY_braille_dots_236            = uint(C.GDK_KEY_braille_dots_236)
	KEY_braille_dots_1236           = uint(C.GDK_KEY_braille_dots_1236)
	KEY_braille_dots_46             = uint(C.GDK_KEY_braille_dots_46)
	KEY_braille_dots_146            = uint(C.GDK_KEY_braille_dots_146)
	KEY_braille_dots_246            = uint(C.GDK_KEY_braille_dots_246)
	KEY_braille_dots_1246           = uint(C.GDK_KEY_braille_dots_1246)
	KEY_braille_dots_346            = uint(C.GDK_KEY_braille_dots_346)
	KEY_braille_dots_1346           = uint(C.GDK_KEY_braille_dots_1346)
	KEY_braille_dots_2346           = uint(C.GDK_KEY_braille_dots_2346)
	KEY_braille_dots_12346          = uint(C.GDK_KEY_braille_dots_12346)
	KEY_braille_dots_56             = uint(C.GDK_KEY_braille_dots_56)
	KEY_braille_dots_156            = uint(C.GDK_KEY_braille_dots_156)
	KEY_braille_dots_256            = uint(C.GDK_KEY_braille_dots_256)
	KEY_braille_dots_1256           = uint(C.GDK_KEY_braille_dots_1256)
	KEY_braille_dots_356            = uint(C.GDK_KEY_braille_dots_356)
	KEY_braille_dots_1356           = uint(C.GDK_KEY_braille_dots_1356)
	KEY_braille_dots_2356           = uint(C.GDK_KEY_braille_dots_2356)
	KEY_braille_dots_12356          = uint(C.GDK_KEY_braille_dots_12356)
	KEY_braille_dots_456            = uint(C.GDK_KEY_braille_dots_456)
	KEY_braille_dots_1456           = uint(C.GDK_KEY_braille_dots_1456)
	KEY_braille_dots_2456           = uint(C.GDK_KEY_braille_dots_2456)
	KEY_braille_dots_12456          = uint(C.GDK_KEY_braille_dots_12456)
	KEY_braille_dots_3456           = uint(C.GDK_KEY_braille_dots_3456)
	KEY_braille_dots_13456          = uint(C.GDK_KEY_braille_dots_13456)
	KEY_braille_dots_23456          = uint(C.GDK_KEY_braille_dots_23456)
	KEY_braille_dots_123456         = uint(C.GDK_KEY_braille_dots_123456)
	KEY_braille_dots_7              = uint(C.GDK_KEY_braille_dots_7)
	KEY_braille_dots_17             = uint(C.GDK_KEY_braille_dots_17)
	KEY_braille_dots_27             = uint(C.GDK_KEY_braille_dots_27)
	KEY_braille_dots_127            = uint(C.GDK_KEY_braille_dots_127)
	KEY_braille_dots_37             = uint(C.GDK_KEY_braille_dots_37)
	KEY_braille_dots_137            = uint(C.GDK_KEY_braille_dots_137)
	KEY_braille_dots_237            = uint(C.GDK_KEY_braille_dots_237)
	KEY_braille_dots_1237           = uint(C.GDK_KEY_braille_dots_1237)
	KEY_braille_dots_47             = uint(C.GDK_KEY_braille_dots_47)
	KEY_braille_dots_147            = uint(C.GDK_KEY_braille_dots_147)
	KEY_braille_dots_247            = uint(C.GDK_KEY_braille_dots_247)
	KEY_braille_dots_1247           = uint(C.GDK_KEY_braille_dots_1247)
	KEY_braille_dots_347            = uint(C.GDK_KEY_braille_dots_347)
	KEY_braille_dots_1347           = uint(C.GDK_KEY_braille_dots_1347)
	KEY_braille_dots_2347           = uint(C.GDK_KEY_braille_dots_2347)
	KEY_braille_dots_12347          = uint(C.GDK_KEY_braille_dots_12347)
	KEY_braille_dots_57             = uint(C.GDK_KEY_braille_dots_57)
	KEY_braille_dots_157            = uint(C.GDK_KEY_braille_dots_157)
	KEY_braille_dots_257            = uint(C.GDK_KEY_braille_dots_257)
	KEY_braille_dots_1257           = uint(C.GDK_KEY_braille_dots_1257)
	KEY_braille_dots_357            = uint(C.GDK_KEY_braille_dots_357)
	KEY_braille_dots_1357           = uint(C.GDK_KEY_braille_dots_1357)
	KEY_braille_dots_2357           = uint(C.GDK_KEY_braille_dots_2357)
	KEY_braille_dots_12357          = uint(C.GDK_KEY_braille_dots_12357)
	KEY_braille_dots_457            = uint(C.GDK_KEY_braille_dots_457)
	KEY_braille_dots_1457           = uint(C.GDK_KEY_braille_dots_1457)
	KEY_braille_dots_2457           = uint(C.GDK_KEY_braille_dots_2457)
	KEY_braille_dots_12457          = uint(C.GDK_KEY_braille_dots_12457)
	KEY_braille_dots_3457           = uint(C.GDK_KEY_braille_dots_3457)
	KEY_braille_dots_13457          = uint(C.GDK_KEY_braille_dots_13457)
	KEY_braille_dots_23457          = uint(C.GDK_KEY_braille_dots_23457)
	KEY_braille_dots_123457         = uint(C.GDK_KEY_braille_dots_123457)
	KEY_braille_dots_67             = uint(C.GDK_KEY_braille_dots_67)
	KEY_braille_dots_167            = uint(C.GDK_KEY_braille_dots_167)
	KEY_braille_dots_267            = uint(C.GDK_KEY_braille_dots_267)
	KEY_braille_dots_1267           = uint(C.GDK_KEY_braille_dots_1267)
	KEY_braille_dots_367            = uint(C.GDK_KEY_braille_dots_367)
	KEY_braille_dots_1367           = uint(C.GDK_KEY_braille_dots_1367)
	KEY_braille_dots_2367           = uint(C.GDK_KEY_braille_dots_2367)
	KEY_braille_dots_12367          = uint(C.GDK_KEY_braille_dots_12367)
	KEY_braille_dots_467            = uint(C.GDK_KEY_braille_dots_467)
	KEY_braille_dots_1467           = uint(C.GDK_KEY_braille_dots_1467)
	KEY_braille_dots_2467           = uint(C.GDK_KEY_braille_dots_2467)
	KEY_braille_dots_12467          = uint(C.GDK_KEY_braille_dots_12467)
	KEY_braille_dots_3467           = uint(C.GDK_KEY_braille_dots_3467)
	KEY_braille_dots_13467          = uint(C.GDK_KEY_braille_dots_13467)
	KEY_braille_dots_23467          = uint(C.GDK_KEY_braille_dots_23467)
	KEY_braille_dots_123467         = uint(C.GDK_KEY_braille_dots_123467)
	KEY_braille_dots_567            = uint(C.GDK_KEY_braille_dots_567)
	KEY_braille_dots_1567           = uint(C.GDK_KEY_braille_dots_1567)
	KEY_braille_dots_2567           = uint(C.GDK_KEY_braille_dots_2567)
	KEY_braille_dots_12567          = uint(C.GDK_KEY_braille_dots_12567)
	KEY_braille_dots_3567           = uint(C.GDK_KEY_braille_dots_3567)
	KEY_braille_dots_13567          = uint(C.GDK_KEY_braille_dots_13567)
	KEY_braille_dots_23567          = uint(C.GDK_KEY_braille_dots_23567)
	KEY_braille_dots_123567         = uint(C.GDK_KEY_braille_dots_123567)
	KEY_braille_dots_4567           = uint(C.GDK_KEY_braille_dots_4567)
	KEY_braille_dots_14567          = uint(C.GDK_KEY_braille_dots_14567)
	KEY_braille_dots_24567          = uint(C.GDK_KEY_braille_dots_24567)
	KEY_braille_dots_124567         = uint(C.GDK_KEY_braille_dots_124567)
	KEY_braille_dots_34567          = uint(C.GDK_KEY_braille_dots_34567)
	KEY_braille_dots_134567         = uint(C.GDK_KEY_braille_dots_134567)
	KEY_braille_dots_234567         = uint(C.GDK_KEY_braille_dots_234567)
	KEY_braille_dots_1234567        = uint(C.GDK_KEY_braille_dots_1234567)
	KEY_braille_dots_8              = uint(C.GDK_KEY_braille_dots_8)
	KEY_braille_dots_18             = uint(C.GDK_KEY_braille_dots_18)
	KEY_braille_dots_28             = uint(C.GDK_KEY_braille_dots_28)
	KEY_braille_dots_128            = uint(C.GDK_KEY_braille_dots_128)
	KEY_braille_dots_38             = uint(C.GDK_KEY_braille_dots_38)
	KEY_braille_dots_138            = uint(C.GDK_KEY_braille_dots_138)
	KEY_braille_dots_238            = uint(C.GDK_KEY_braille_dots_238)
	KEY_braille_dots_1238           = uint(C.GDK_KEY_braille_dots_1238)
	KEY_braille_dots_48             = uint(C.GDK_KEY_braille_dots_48)
	KEY_braille_dots_148            = uint(C.GDK_KEY_braille_dots_148)
	KEY_braille_dots_248            = uint(C.GDK_KEY_braille_dots_248)
	KEY_braille_dots_1248           = uint(C.GDK_KEY_braille_dots_1248)
	KEY_braille_dots_348            = uint(C.GDK_KEY_braille_dots_348)
	KEY_braille_dots_1348           = uint(C.GDK_KEY_braille_dots_1348)
	KEY_braille_dots_2348           = uint(C.GDK_KEY_braille_dots_2348)
	KEY_braille_dots_12348          = uint(C.GDK_KEY_braille_dots_12348)
	KEY_braille_dots_58             = uint(C.GDK_KEY_braille_dots_58)
	KEY_braille_dots_158            = uint(C.GDK_KEY_braille_dots_158)
	KEY_braille_dots_258            = uint(C.GDK_KEY_braille_dots_258)
	KEY_braille_dots_1258           = uint(C.GDK_KEY_braille_dots_1258)
	KEY_braille_dots_358            = uint(C.GDK_KEY_braille_dots_358)
	KEY_braille_dots_1358           = uint(C.GDK_KEY_braille_dots_1358)
	KEY_braille_dots_2358           = uint(C.GDK_KEY_braille_dots_2358)
	KEY_braille_dots_12358          = uint(C.GDK_KEY_braille_dots_12358)
	KEY_braille_dots_458            = uint(C.GDK_KEY_braille_dots_458)
	KEY_braille_dots_1458           = uint(C.GDK_KEY_braille_dots_1458)
	KEY_braille_dots_2458           = uint(C.GDK_KEY_braille_dots_2458)
	KEY_braille_dots_12458          = uint(C.GDK_KEY_braille_dots_12458)
	KEY_braille_dots_3458           = uint(C.GDK_KEY_braille_dots_3458)
	KEY_braille_dots_13458          = uint(C.GDK_KEY_braille_dots_13458)
	KEY_braille_dots_23458          = uint(C.GDK_KEY_braille_dots_23458)
	KEY_braille_dots_123458         = uint(C.GDK_KEY_braille_dots_123458)
	KEY_braille_dots_68             = uint(C.GDK_KEY_braille_dots_68)
	KEY_braille_dots_168            = uint(C.GDK_KEY_braille_dots_168)
	KEY_braille_dots_268            = uint(C.GDK_KEY_braille_dots_268)
	KEY_braille_dots_1268           = uint(C.GDK_KEY_braille_dots_1268)
	KEY_braille_dots_368            = uint(C.GDK_KEY_braille_dots_368)
	KEY_braille_dots_1368           = uint(C.GDK_KEY_braille_dots_1368)
	KEY_braille_dots_2368           = uint(C.GDK_KEY_braille_dots_2368)
	KEY_braille_dots_12368          = uint(C.GDK_KEY_braille_dots_12368)
	KEY_braille_dots_468            = uint(C.GDK_KEY_braille_dots_468)
	KEY_braille_dots_1468           = uint(C.GDK_KEY_braille_dots_1468)
	KEY_braille_dots_2468           = uint(C.GDK_KEY_braille_dots_2468)
	KEY_braille_dots_12468          = uint(C.GDK_KEY_braille_dots_12468)
	KEY_braille_dots_3468           = uint(C.GDK_KEY_braille_dots_3468)
	KEY_braille_dots_13468          = uint(C.GDK_KEY_braille_dots_13468)
	KEY_braille_dots_23468          = uint(C.GDK_KEY_braille_dots_23468)
	KEY_braille_dots_123468         = uint(C.GDK_KEY_braille_dots_123468)
	KEY_braille_dots_568            = uint(C.GDK_KEY_braille_dots_568)
	KEY_braille_dots_1568           = uint(C.GDK_KEY_braille_dots_1568)
	KEY_braille_dots_2568           = uint(C.GDK_KEY_braille_dots_2568)
	KEY_braille_dots_12568          = uint(C.GDK_KEY_braille_dots_12568)
	KEY_braille_dots_3568           = uint(C.GDK_KEY_braille_dots_3568)
	KEY_braille_dots_13568          = uint(C.GDK_KEY_braille_dots_13568)
	KEY_braille_dots_23568          = uint(C.GDK_KEY_braille_dots_23568)
	KEY_braille_dots_123568         = uint(C.GDK_KEY_braille_dots_123568)
	KEY_braille_dots_4568           = uint(C.GDK_KEY_braille_dots_4568)
	KEY_braille_dots_14568          = uint(C.GDK_KEY_braille_dots_14568)
	KEY_braille_dots_24568          = uint(C.GDK_KEY_braille_dots_24568)
	KEY_braille_dots_124568         = uint(C.GDK_KEY_braille_dots_124568)
	KEY_braille_dots_34568          = uint(C.GDK_KEY_braille_dots_34568)
	KEY_braille_dots_134568         = uint(C.GDK_KEY_braille_dots_134568)
	KEY_braille_dots_234568         = uint(C.GDK_KEY_braille_dots_234568)
	KEY_braille_dots_1234568        = uint(C.GDK_KEY_braille_dots_1234568)
	KEY_braille_dots_78             = uint(C.GDK_KEY_braille_dots_78)
	KEY_braille_dots_178            = uint(C.GDK_KEY_braille_dots_178)
	KEY_braille_dots_278            = uint(C.GDK_KEY_braille_dots_278)
	KEY_braille_dots_1278           = uint(C.GDK_KEY_braille_dots_1278)
	KEY_braille_dots_378            = uint(C.GDK_KEY_braille_dots_378)
	KEY_braille_dots_1378           = uint(C.GDK_KEY_braille_dots_1378)
	KEY_braille_dots_2378           = uint(C.GDK_KEY_braille_dots_2378)
	KEY_braille_dots_12378          = uint(C.GDK_KEY_braille_dots_12378)
	KEY_braille_dots_478            = uint(C.GDK_KEY_braille_dots_478)
	KEY_braille_dots_1478           = uint(C.GDK_KEY_braille_dots_1478)
	KEY_braille_dots_2478           = uint(C.GDK_KEY_braille_dots_2478)
	KEY_braille_dots_12478          = uint(C.GDK_KEY_braille_dots_12478)
	KEY_braille_dots_3478           = uint(C.GDK_KEY_braille_dots_3478)
	KEY_braille_dots_13478          = uint(C.GDK_KEY_braille_dots_13478)
	KEY_braille_dots_23478          = uint(C.GDK_KEY_braille_dots_23478)
	KEY_braille_dots_123478         = uint(C.GDK_KEY_braille_dots_123478)
	KEY_braille_dots_578            = uint(C.GDK_KEY_braille_dots_578)
	KEY_braille_dots_1578           = uint(C.GDK_KEY_braille_dots_1578)
	KEY_braille_dots_2578           = uint(C.GDK_KEY_braille_dots_2578)
	KEY_braille_dots_12578          = uint(C.GDK_KEY_braille_dots_12578)
	KEY_braille_dots_3578           = uint(C.GDK_KEY_braille_dots_3578)
	KEY_braille_dots_13578          = uint(C.GDK_KEY_braille_dots_13578)
	KEY_braille_dots_23578          = uint(C.GDK_KEY_braille_dots_23578)
	KEY_braille_dots_123578         = uint(C.GDK_KEY_braille_dots_123578)
	KEY_braille_dots_4578           = uint(C.GDK_KEY_braille_dots_4578)
	KEY_braille_dots_14578          = uint(C.GDK_KEY_braille_dots_14578)
	KEY_braille_dots_24578          = uint(C.GDK_KEY_braille_dots_24578)
	KEY_braille_dots_124578         = uint(C.GDK_KEY_braille_dots_124578)
	KEY_braille_dots_34578          = uint(C.GDK_KEY_braille_dots_34578)
	KEY_braille_dots_134578         = uint(C.GDK_KEY_braille_dots_134578)
	KEY_braille_dots_234578         = uint(C.GDK_KEY_braille_dots_234578)
	KEY_braille_dots_1234578        = uint(C.GDK_KEY_braille_dots_1234578)
	KEY_braille_dots_678            = uint(C.GDK_KEY_braille_dots_678)
	KEY_braille_dots_1678           = uint(C.GDK_KEY_braille_dots_1678)
	KEY_braille_dots_2678           = uint(C.GDK_KEY_braille_dots_2678)
	KEY_braille_dots_12678          = uint(C.GDK_KEY_braille_dots_12678)
	KEY_braille_dots_3678           = uint(C.GDK_KEY_braille_dots_3678)
	KEY_braille_dots_13678          = uint(C.GDK_KEY_braille_dots_13678)
	KEY_braille_dots_23678          = uint(C.GDK_KEY_braille_dots_23678)
	KEY_braille_dots_123678         = uint(C.GDK_KEY_braille_dots_123678)
	KEY_braille_dots_4678           = uint(C.GDK_KEY_braille_dots_4678)
	KEY_braille_dots_14678          = uint(C.GDK_KEY_braille_dots_14678)
	KEY_braille_dots_24678          = uint(C.GDK_KEY_braille_dots_24678)
	KEY_braille_dots_124678         = uint(C.GDK_KEY_braille_dots_124678)
	KEY_braille_dots_34678          = uint(C.GDK_KEY_braille_dots_34678)
	KEY_braille_dots_134678         = uint(C.GDK_KEY_braille_dots_134678)
	KEY_braille_dots_234678         = uint(C.GDK_KEY_braille_dots_234678)
	KEY_braille_dots_1234678        = uint(C.GDK_KEY_braille_dots_1234678)
	KEY_braille_dots_5678           = uint(C.GDK_KEY_braille_dots_5678)
	KEY_braille_dots_15678          = uint(C.GDK_KEY_braille_dots_15678)
	KEY_braille_dots_25678          = uint(C.GDK_KEY_braille_dots_25678)
	KEY_braille_dots_125678         = uint(C.GDK_KEY_braille_dots_125678)
	KEY_braille_dots_35678          = uint(C.GDK_KEY_braille_dots_35678)
	KEY_braille_dots_135678         = uint(C.GDK_KEY_braille_dots_135678)
	KEY_braille_dots_235678         = uint(C.GDK_KEY_braille_dots_235678)
	KEY_braille_dots_1235678        = uint(C.GDK_KEY_braille_dots_1235678)
	KEY_braille_dots_45678          = uint(C.GDK_KEY_braille_dots_45678)
	KEY_braille_dots_145678         = uint(C.GDK_KEY_braille_dots_145678)
	KEY_braille_dots_245678         = uint(C.GDK_KEY_braille_dots_245678)
	KEY_braille_dots_1245678        = uint(C.GDK_KEY_braille_dots_1245678)
	KEY_braille_dots_345678         = uint(C.GDK_KEY_braille_dots_345678)
	KEY_braille_dots_1345678        = uint(C.GDK_KEY_braille_dots_1345678)
	KEY_braille_dots_2345678        = uint(C.GDK_KEY_braille_dots_2345678)
	KEY_braille_dots_12345678       = uint(C.GDK_KEY_braille_dots_12345678)
	KEY_Sinh_ng                     = uint(C.GDK_KEY_Sinh_ng)
	KEY_Sinh_h2                     = uint(C.GDK_KEY_Sinh_h2)
	KEY_Sinh_a                      = uint(C.GDK_KEY_Sinh_a)
	KEY_Sinh_aa                     = uint(C.GDK_KEY_Sinh_aa)
	KEY_Sinh_ae                     = uint(C.GDK_KEY_Sinh_ae)
	KEY_Sinh_aee                    = uint(C.GDK_KEY_Sinh_aee)
	KEY_Sinh_i                      = uint(C.GDK_KEY_Sinh_i)
	KEY_Sinh_ii                     = uint(C.GDK_KEY_Sinh_ii)
	KEY_Sinh_u                      = uint(C.GDK_KEY_Sinh_u)
	KEY_Sinh_uu                     = uint(C.GDK_KEY_Sinh_uu)
	KEY_Sinh_ri                     = uint(C.GDK_KEY_Sinh_ri)
	KEY_Sinh_rii                    = uint(C.GDK_KEY_Sinh_rii)
	KEY_Sinh_lu                     = uint(C.GDK_KEY_Sinh_lu)
	KEY_Sinh_luu                    = uint(C.GDK_KEY_Sinh_luu)
	KEY_Sinh_e                      = uint(C.GDK_KEY_Sinh_e)
	KEY_Sinh_ee                     = uint(C.GDK_KEY_Sinh_ee)
	KEY_Sinh_ai                     = uint(C.GDK_KEY_Sinh_ai)
	KEY_Sinh_o                      = uint(C.GDK_KEY_Sinh_o)
	KEY_Sinh_oo                     = uint(C.GDK_KEY_Sinh_oo)
	KEY_Sinh_au                     = uint(C.GDK_KEY_Sinh_au)
	KEY_Sinh_ka                     = uint(C.GDK_KEY_Sinh_ka)
	KEY_Sinh_kha                    = uint(C.GDK_KEY_Sinh_kha)
	KEY_Sinh_ga                     = uint(C.GDK_KEY_Sinh_ga)
	KEY_Sinh_gha                    = uint(C.GDK_KEY_Sinh_gha)
	KEY_Sinh_ng2                    = uint(C.GDK_KEY_Sinh_ng2)
	KEY_Sinh_nga                    = uint(C.GDK_KEY_Sinh_nga)
	KEY_Sinh_ca                     = uint(C.GDK_KEY_Sinh_ca)
	KEY_Sinh_cha                    = uint(C.GDK_KEY_Sinh_cha)
	KEY_Sinh_ja                     = uint(C.GDK_KEY_Sinh_ja)
	KEY_Sinh_jha                    = uint(C.GDK_KEY_Sinh_jha)
	KEY_Sinh_nya                    = uint(C.GDK_KEY_Sinh_nya)
	KEY_Sinh_jnya                   = uint(C.GDK_KEY_Sinh_jnya)
	KEY_Sinh_nja                    = uint(C.GDK_KEY_Sinh_nja)
	KEY_Sinh_tta                    = uint(C.GDK_KEY_Sinh_tta)
	KEY_Sinh_ttha                   = uint(C.GDK_KEY_Sinh_ttha)
	KEY_Sinh_dda                    = uint(C.GDK_KEY_Sinh_dda)
	KEY_Sinh_ddha                   = uint(C.GDK_KEY_Sinh_ddha)
	KEY_Sinh_nna                    = uint(C.GDK_KEY_Sinh_nna)
	KEY_Sinh_ndda                   = uint(C.GDK_KEY_Sinh_ndda)
	KEY_Sinh_tha                    = uint(C.GDK_KEY_Sinh_tha)
	KEY_Sinh_thha                   = uint(C.GDK_KEY_Sinh_thha)
	KEY_Sinh_dha                    = uint(C.GDK_KEY_Sinh_dha)
	KEY_Sinh_dhha                   = uint(C.GDK_KEY_Sinh_dhha)
	KEY_Sinh_na                     = uint(C.GDK_KEY_Sinh_na)
	KEY_Sinh_ndha                   = uint(C.GDK_KEY_Sinh_ndha)
	KEY_Sinh_pa                     = uint(C.GDK_KEY_Sinh_pa)
	KEY_Sinh_pha                    = uint(C.GDK_KEY_Sinh_pha)
	KEY_Sinh_ba                     = uint(C.GDK_KEY_Sinh_ba)
	KEY_Sinh_bha                    = uint(C.GDK_KEY_Sinh_bha)
	KEY_Sinh_ma                     = uint(C.GDK_KEY_Sinh_ma)
	KEY_Sinh_mba                    = uint(C.GDK_KEY_Sinh_mba)
	KEY_Sinh_ya                     = uint(C.GDK_KEY_Sinh_ya)
	KEY_Sinh_ra                     = uint(C.GDK_KEY_Sinh_ra)
	KEY_Sinh_la                     = uint(C.GDK_KEY_Sinh_la)
	KEY_Sinh_va                     = uint(C.GDK_KEY_Sinh_va)
	KEY_Sinh_sha                    = uint(C.GDK_KEY_Sinh_sha)
	KEY_Sinh_ssha                   = uint(C.GDK_KEY_Sinh_ssha)
	KEY_Sinh_sa                     = uint(C.GDK_KEY_Sinh_sa)
	KEY_Sinh_ha                     = uint(C.GDK_KEY_Sinh_ha)
	KEY_Sinh_lla                    = uint(C.GDK_KEY_Sinh_lla)
	KEY_Sinh_fa                     = uint(C.GDK_KEY_Sinh_fa)
	KEY_Sinh_al                     = uint(C.GDK_KEY_Sinh_al)
	KEY_Sinh_aa2                    = uint(C.GDK_KEY_Sinh_aa2)
	KEY_Sinh_ae2                    = uint(C.GDK_KEY_Sinh_ae2)
	KEY_Sinh_aee2                   = uint(C.GDK_KEY_Sinh_aee2)
	KEY_Sinh_i2                     = uint(C.GDK_KEY_Sinh_i2)
	KEY_Sinh_ii2                    = uint(C.GDK_KEY_Sinh_ii2)
	KEY_Sinh_u2                     = uint(C.GDK_KEY_Sinh_u2)
	KEY_Sinh_uu2                    = uint(C.GDK_KEY_Sinh_uu2)
	KEY_Sinh_ru2                    = uint(C.GDK_KEY_Sinh_ru2)
	KEY_Sinh_e2                     = uint(C.GDK_KEY_Sinh_e2)
	KEY_Sinh_ee2                    = uint(C.GDK_KEY_Sinh_ee2)
	KEY_Sinh_ai2                    = uint(C.GDK_KEY_Sinh_ai2)
	KEY_Sinh_o2                     = uint(C.GDK_KEY_Sinh_o2)
	KEY_Sinh_oo2                    = uint(C.GDK_KEY_Sinh_oo2)
	KEY_Sinh_au2                    = uint(C.GDK_KEY_Sinh_au2)
	KEY_Sinh_lu2                    = uint(C.GDK_KEY_Sinh_lu2)
	KEY_Sinh_ruu2                   = uint(C.GDK_KEY_Sinh_ruu2)
	KEY_Sinh_luu2                   = uint(C.GDK_KEY_Sinh_luu2)
	KEY_Sinh_kunddaliya             = uint(C.GDK_KEY_Sinh_kunddaliya)
	KEY_ModeLock                    = uint(C.GDK_KEY_ModeLock)
	KEY_MonBrightnessUp             = uint(C.GDK_KEY_MonBrightnessUp)
	KEY_MonBrightnessDown           = uint(C.GDK_KEY_MonBrightnessDown)
	KEY_KbdLightOnOff               = uint(C.GDK_KEY_KbdLightOnOff)
	KEY_KbdBrightnessUp             = uint(C.GDK_KEY_KbdBrightnessUp)
	KEY_KbdBrightnessDown           = uint(C.GDK_KEY_KbdBrightnessDown)
	KEY_Standby                     = uint(C.GDK_KEY_Standby)
	KEY_AudioLowerVolume            = uint(C.GDK_KEY_AudioLowerVolume)
	KEY_AudioMute                   = uint(C.GDK_KEY_AudioMute)
	KEY_AudioRaiseVolume            = uint(C.GDK_KEY_AudioRaiseVolume)
	KEY_AudioPlay                   = uint(C.GDK_KEY_AudioPlay)
	KEY_AudioStop                   = uint(C.GDK_KEY_AudioStop)
	KEY_AudioPrev                   = uint(C.GDK_KEY_AudioPrev)
	KEY_AudioNext                   = uint(C.GDK_KEY_AudioNext)
	KEY_HomePage                    = uint(C.GDK_KEY_HomePage)
	KEY_Mail                        = uint(C.GDK_KEY_Mail)
	KEY_Start                       = uint(C.GDK_KEY_Start)
	KEY_Search                      = uint(C.GDK_KEY_Search)
	KEY_AudioRecord                 = uint(C.GDK_KEY_AudioRecord)
	KEY_Calculator                  = uint(C.GDK_KEY_Calculator)
	KEY_Memo                        = uint(C.GDK_KEY_Memo)
	KEY_ToDoList                    = uint(C.GDK_KEY_ToDoList)
	KEY_Calendar                    = uint(C.GDK_KEY_Calendar)
	KEY_PowerDown                   = uint(C.GDK_KEY_PowerDown)
	KEY_ContrastAdjust              = uint(C.GDK_KEY_ContrastAdjust)
	KEY_RockerUp                    = uint(C.GDK_KEY_RockerUp)
	KEY_RockerDown                  = uint(C.GDK_KEY_RockerDown)
	KEY_RockerEnter                 = uint(C.GDK_KEY_RockerEnter)
	KEY_Back                        = uint(C.GDK_KEY_Back)
	KEY_Forward                     = uint(C.GDK_KEY_Forward)
	KEY_Stop                        = uint(C.GDK_KEY_Stop)
	KEY_Refresh                     = uint(C.GDK_KEY_Refresh)
	KEY_PowerOff                    = uint(C.GDK_KEY_PowerOff)
	KEY_WakeUp                      = uint(C.GDK_KEY_WakeUp)
	KEY_Eject                       = uint(C.GDK_KEY_Eject)
	KEY_ScreenSaver                 = uint(C.GDK_KEY_ScreenSaver)
	KEY_WWW                         = uint(C.GDK_KEY_WWW)
	KEY_Sleep                       = uint(C.GDK_KEY_Sleep)
	KEY_Favorites                   = uint(C.GDK_KEY_Favorites)
	KEY_AudioPause                  = uint(C.GDK_KEY_AudioPause)
	KEY_AudioMedia                  = uint(C.GDK_KEY_AudioMedia)
	KEY_MyComputer                  = uint(C.GDK_KEY_MyComputer)
	KEY_VendorHome                  = uint(C.GDK_KEY_VendorHome)
	KEY_LightBulb                   = uint(C.GDK_KEY_LightBulb)
	KEY_Shop                        = uint(C.GDK_KEY_Shop)
	KEY_History                     = uint(C.GDK_KEY_History)
	KEY_OpenURL                     = uint(C.GDK_KEY_OpenURL)
	KEY_AddFavorite                 = uint(C.GDK_KEY_AddFavorite)
	KEY_HotLinks                    = uint(C.GDK_KEY_HotLinks)
	KEY_BrightnessAdjust            = uint(C.GDK_KEY_BrightnessAdjust)
	KEY_Finance                     = uint(C.GDK_KEY_Finance)
	KEY_Community                   = uint(C.GDK_KEY_Community)
	KEY_AudioRewind                 = uint(C.GDK_KEY_AudioRewind)
	KEY_BackForward                 = uint(C.GDK_KEY_BackForward)
	KEY_Launch0                     = uint(C.GDK_KEY_Launch0)
	KEY_Launch1                     = uint(C.GDK_KEY_Launch1)
	KEY_Launch2                     = uint(C.GDK_KEY_Launch2)
	KEY_Launch3                     = uint(C.GDK_KEY_Launch3)
	KEY_Launch4                     = uint(C.GDK_KEY_Launch4)
	KEY_Launch5                     = uint(C.GDK_KEY_Launch5)
	KEY_Launch6                     = uint(C.GDK_KEY_Launch6)
	KEY_Launch7                     = uint(C.GDK_KEY_Launch7)
	KEY_Launch8                     = uint(C.GDK_KEY_Launch8)
	KEY_Launch9                     = uint(C.GDK_KEY_Launch9)
	KEY_LaunchA                     = uint(C.GDK_KEY_LaunchA)
	KEY_LaunchB                     = uint(C.GDK_KEY_LaunchB)
	KEY_LaunchC                     = uint(C.GDK_KEY_LaunchC)
	KEY_LaunchD                     = uint(C.GDK_KEY_LaunchD)
	KEY_LaunchE                     = uint(C.GDK_KEY_LaunchE)
	KEY_LaunchF                     = uint(C.GDK_KEY_LaunchF)
	KEY_ApplicationLeft             = uint(C.GDK_KEY_ApplicationLeft)
	KEY_ApplicationRight            = uint(C.GDK_KEY_ApplicationRight)
	KEY_Book                        = uint(C.GDK_KEY_Book)
	KEY_CD                          = uint(C.GDK_KEY_CD)
	KEY_WindowClear                 = uint(C.GDK_KEY_WindowClear)
	KEY_Close                       = uint(C.GDK_KEY_Close)
	KEY_Copy                        = uint(C.GDK_KEY_Copy)
	KEY_Cut                         = uint(C.GDK_KEY_Cut)
	KEY_Display                     = uint(C.GDK_KEY_Display)
	KEY_DOS                         = uint(C.GDK_KEY_DOS)
	KEY_Documents                   = uint(C.GDK_KEY_Documents)
	KEY_Excel                       = uint(C.GDK_KEY_Excel)
	KEY_Explorer                    = uint(C.GDK_KEY_Explorer)
	KEY_Game                        = uint(C.GDK_KEY_Game)
	KEY_Go                          = uint(C.GDK_KEY_Go)
	KEY_iTouch                      = uint(C.GDK_KEY_iTouch)
	KEY_LogOff                      = uint(C.GDK_KEY_LogOff)
	KEY_Market                      = uint(C.GDK_KEY_Market)
	KEY_Meeting                     = uint(C.GDK_KEY_Meeting)
	KEY_MenuKB                      = uint(C.GDK_KEY_MenuKB)
	KEY_MenuPB                      = uint(C.GDK_KEY_MenuPB)
	KEY_MySites                     = uint(C.GDK_KEY_MySites)
	KEY_New                         = uint(C.GDK_KEY_New)
	KEY_News                        = uint(C.GDK_KEY_News)
	KEY_OfficeHome                  = uint(C.GDK_KEY_OfficeHome)
	KEY_Open                        = uint(C.GDK_KEY_Open)
	KEY_Option                      = uint(C.GDK_KEY_Option)
	KEY_Paste                       = uint(C.GDK_KEY_Paste)
	KEY_Phone                       = uint(C.GDK_KEY_Phone)
	KEY_Reply                       = uint(C.GDK_KEY_Reply)
	KEY_Reload                      = uint(C.GDK_KEY_Reload)
	KEY_RotateWindows               = uint(C.GDK_KEY_RotateWindows)
	KEY_RotationPB                  = uint(C.GDK_KEY_RotationPB)
	KEY_RotationKB                  = uint(C.GDK_KEY_RotationKB)
	KEY_Save                        = uint(C.GDK_KEY_Save)
	KEY_ScrollUp                    = uint(C.GDK_KEY_ScrollUp)
	KEY_ScrollDown                  = uint(C.GDK_KEY_ScrollDown)
	KEY_ScrollClick                 = uint(C.GDK_KEY_ScrollClick)
	KEY_Send                        = uint(C.GDK_KEY_Send)
	KEY_Spell                       = uint(C.GDK_KEY_Spell)
	KEY_SplitScreen                 = uint(C.GDK_KEY_SplitScreen)
	KEY_Support                     = uint(C.GDK_KEY_Support)
	KEY_TaskPane                    = uint(C.GDK_KEY_TaskPane)
	KEY_Terminal                    = uint(C.GDK_KEY_Terminal)
	KEY_Tools                       = uint(C.GDK_KEY_Tools)
	KEY_Travel                      = uint(C.GDK_KEY_Travel)
	KEY_UserPB                      = uint(C.GDK_KEY_UserPB)
	KEY_User1KB                     = uint(C.GDK_KEY_User1KB)
	KEY_User2KB                     = uint(C.GDK_KEY_User2KB)
	KEY_Video                       = uint(C.GDK_KEY_Video)
	KEY_WheelButton                 = uint(C.GDK_KEY_WheelButton)
	KEY_Word                        = uint(C.GDK_KEY_Word)
	KEY_Xfer                        = uint(C.GDK_KEY_Xfer)
	KEY_ZoomIn                      = uint(C.GDK_KEY_ZoomIn)
	KEY_ZoomOut                     = uint(C.GDK_KEY_ZoomOut)
	KEY_Away                        = uint(C.GDK_KEY_Away)
	KEY_Messenger                   = uint(C.GDK_KEY_Messenger)
	KEY_WebCam                      = uint(C.GDK_KEY_WebCam)
	KEY_MailForward                 = uint(C.GDK_KEY_MailForward)
	KEY_Pictures                    = uint(C.GDK_KEY_Pictures)
	KEY_Music                       = uint(C.GDK_KEY_Music)
	KEY_Battery                     = uint(C.GDK_KEY_Battery)
	KEY_Bluetooth                   = uint(C.GDK_KEY_Bluetooth)
	KEY_WLAN                        = uint(C.GDK_KEY_WLAN)
	KEY_UWB                         = uint(C.GDK_KEY_UWB)
	KEY_AudioForward                = uint(C.GDK_KEY_AudioForward)
	KEY_AudioRepeat                 = uint(C.GDK_KEY_AudioRepeat)
	KEY_AudioRandomPlay             = uint(C.GDK_KEY_AudioRandomPlay)
	KEY_Subtitle                    = uint(C.GDK_KEY_Subtitle)
	KEY_AudioCycleTrack             = uint(C.GDK_KEY_AudioCycleTrack)
	KEY_CycleAngle                  = uint(C.GDK_KEY_CycleAngle)
	KEY_FrameBack                   = uint(C.GDK_KEY_FrameBack)
	KEY_FrameForward                = uint(C.GDK_KEY_FrameForward)
	KEY_Time                        = uint(C.GDK_KEY_Time)
	KEY_SelectButton                = uint(C.GDK_KEY_SelectButton)
	KEY_View                        = uint(C.GDK_KEY_View)
	KEY_TopMenu                     = uint(C.GDK_KEY_TopMenu)
	KEY_Red                         = uint(C.GDK_KEY_Red)
	KEY_Green                       = uint(C.GDK_KEY_Green)
	KEY_Yellow                      = uint(C.GDK_KEY_Yellow)
	KEY_Blue                        = uint(C.GDK_KEY_Blue)
	KEY_Suspend                     = uint(C.GDK_KEY_Suspend)
	KEY_Hibernate                   = uint(C.GDK_KEY_Hibernate)
	KEY_TouchpadToggle              = uint(C.GDK_KEY_TouchpadToggle)
	KEY_TouchpadOn                  = uint(C.GDK_KEY_TouchpadOn)
	KEY_TouchpadOff                 = uint(C.GDK_KEY_TouchpadOff)
	KEY_AudioMicMute                = uint(C.GDK_KEY_AudioMicMute)
	KEY_Switch_VT_1                 = uint(C.GDK_KEY_Switch_VT_1)
	KEY_Switch_VT_2                 = uint(C.GDK_KEY_Switch_VT_2)
	KEY_Switch_VT_3                 = uint(C.GDK_KEY_Switch_VT_3)
	KEY_Switch_VT_4                 = uint(C.GDK_KEY_Switch_VT_4)
	KEY_Switch_VT_5                 = uint(C.GDK_KEY_Switch_VT_5)
	KEY_Switch_VT_6                 = uint(C.GDK_KEY_Switch_VT_6)
	KEY_Switch_VT_7                 = uint(C.GDK_KEY_Switch_VT_7)
	KEY_Switch_VT_8                 = uint(C.GDK_KEY_Switch_VT_8)
	KEY_Switch_VT_9                 = uint(C.GDK_KEY_Switch_VT_9)
	KEY_Switch_VT_10                = uint(C.GDK_KEY_Switch_VT_10)
	KEY_Switch_VT_11                = uint(C.GDK_KEY_Switch_VT_11)
	KEY_Switch_VT_12                = uint(C.GDK_KEY_Switch_VT_12)
	KEY_Ungrab                      = uint(C.GDK_KEY_Ungrab)
	KEY_ClearGrab                   = uint(C.GDK_KEY_ClearGrab)
	KEY_Next_VMode                  = uint(C.GDK_KEY_Next_VMode)
	KEY_Prev_VMode                  = uint(C.GDK_KEY_Prev_VMode)
	KEY_LogWindowTree               = uint(C.GDK_KEY_LogWindowTree)
	KEY_LogGrabInfo                 = uint(C.GDK_KEY_LogGrabInfo)
)
